<?php
/**
 * Copyright 2025 Flex Clam Server for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2025 Flex Clam Server for Plesk
 * @author Flex Antivirus <info@antivirus.flexservices.app>
 * @license Copyright
 */

class IndexController extends pm_Controller_Action{

    private $StatusFlex = 0;
    private $MailServer = "";
    private $MailServerAntivirus = false;
    private $MEFilterFlex = true;
    private $WD = false;
    private $Setup = false;
    private $Licensed = false;


    public function __call($name, $arguments){
 		$this->_status->addMessage('warning','Not Found');
                $this->_redirect('index?call'.$name, [ 'exit' => true ]);
                return;
    }

    public function init(){

        $this->_accessLevel = 'admin';
        
        parent::init();
	$this->Setup = (Modules_FlexClamServer_Settings::Get("Job")=="Init" ? false : true);

       
	$this->view->pageTitle = $this->lmsg('pageTitle');
	$this->view->headLink()->appendStylesheet(pm_Context::getBaseUrl() . 'flex-clam-server.css?'.Date('dmhYis'));
	$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'js/ext-flex-clam-server-library.js?'.Date('dmhYis'));
	$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'js/ext-flex-clam-server-init.js?'.Date('dmhYis'));


	if ($this->Setup){


		if(!pm_Config::get('ShowLicense') && !isset($_SESSION[pm_Context::getModuleInfo()->name]['InitInfo'])){$this->_status->addMessage('info', pm_Locale::lmsg('InitInfo'));$_SESSION[pm_Context::getModuleInfo()->name]['InitInfo']=1;}

		$Status = Modules_FlexClamServer_Settings::Status();

		$this->StatusFlex = $Status["status"];
		$this->MailServer = $Status["MS"];
		$this->MailServerAntivirus = $Status["MSA"];
		$this->WD = $Status["WD"];
		$this->MEFilterFlex = "None";

		if($this->StatusFlex==1){
			$this->_forward('install');
		}else if($this->StatusFlex==2 || $this->StatusFlex==4 || $this->StatusFlex==5){
			pm_View_Status::addError($this->lmsg('Message.StopService',["button" => "<a href='".$this->view->getHelper('baseUrl')->moduleUrl(['action' => "run"])."' onclick=\"this.querySelector('span').classList.add('wait')\" data-loading='true' class='btn btn-primary'><span>".pm_Locale::lmsg('Message.buttonStart') . "</span></a>"]),true);
		}

		if ( $this->StatusFlex == 0){

			if($this->MailServer=="MailEnable"){$this->MEFilterFlex = $Status["mailenablefilter"]; }

			if($this->WD){
				if($this->_getParam('action')!="wd"){
					pm_View_Status::addWarning($this->lmsg('Message.WD',["button" => "<a href='".$this->view->getHelper('baseUrl')->moduleUrl(['action' => "wd"])."/do/0' onclick=\"this.querySelector('span').classList.add('wait')\" data-loading='true' class='btn btn-primary'><span>".  pm_Locale::lmsg('Message.buttonDisable') . "</span></a>"]),true);
				}
			}else{
				if ($this->MailServerAntivirus){
					if ($this->MEFilterFlex == "None") {
						pm_View_Status::addWarning($this->lmsg('Message.CLMailEnable',["button" => "<a href='".$this->view->getHelper('baseUrl')->moduleUrl(['action' => "clfilter"])."/do/1' onclick=\"this.querySelector('span').classList.add('wait')\" data-loading='true' class='btn btn-primary'><span>".  pm_Locale::lmsg('Message.buttonEnable') . "</span></a>"]),true);
					}else if($this->MEFilterFlex!="Flex"){
						pm_View_Status::addWarning($this->lmsg('Message.WDMailEnable',["button" => "<a href='".$this->view->getHelper('baseUrl')->moduleUrl(['action' => "wdfilter"])."/do/0' onclick=\"this.querySelector('span').classList.add('wait')\" data-loading='true' class='btn btn-primary'><span>".  pm_Locale::lmsg('Message.buttonEnable') . "</span></a>"]),true);
					}
				}
			}
		}

		if(Modules_FlexClamServer_Settings::Get("EnableAutoScan","1")=="0"){
			pm_View_Status::addWarning($this->lmsg('Message.Stop',["button" => "<a href='".$this->view->getHelper('baseUrl')->moduleUrl(['action' => "autoscan"])."' onclick=\"this.querySelector('span').classList.add('wait')\" data-loading='true' class='btn btn-primary'><span>". pm_Locale::lmsg('Message.buttonEnable') . "</span></a>"]),true);
		}
        
		$selectab = $this->getRequest()->getParam('action');

        	$this->view->tabs = [
	            [
        	        'title' => $this->lmsg('tabOverview'),
			'controller' => 'index',
                	'action' => 'overview',
	            ],
        	    [
                	'title' => $this->lmsg('tabVirus'),
			'controller' => 'index',
	                'action' => 'virus',
	            ],
        	    [
                	'title' => $this->lmsg('tabTools'),
			'controller' => 'tools',
	                'action' => 'index',
        	        'containerCls' => ($selectab=='tools' || $selectab=='alert' || $selectab=='optimize' ? 'active' : ''),
        	    ],
	            [
        	        'title' => $this->lmsg('tabStats'),
			'controller' => 'index',
                	'action' => 'stats',
	            ],
        	    [
                	'title' => $this->lmsg('tabSettings'),
			'controller' => 'index',
	                'action' => 'settings',
	            ],
        	    [
                	'title' => $this->lmsg('tabLogs'),
			'controller' => 'index',
	                'action' => 'logs',
        	    ],
	        ];


		$this->Licensed = Modules_FlexClamServer_License::isLicenced();

    	}else{
		if(!pm_Config::get('ShowLicense')){ $this->_status->addMessage('info', pm_Locale::lmsg('InitInfo')); }
	}

    }

    public function installAction(){  

	if($this->_getParam('terms')=="status"){

		$pathinfo = pm_ProductInfo::getProductRootDir() . "admin\\bin\\modules\\flex-clam-server\\setup.json";

		$fileManager = new pm_ServerFileManager();
		if (!$fileManager->fileExists($pathinfo)) {
			$this->_helper->json(['status' => -1]);
		}else{

			$percent = 0;
			do {
				if (!$fileManager->fileExists($pathinfo)) {
					break;
				}

				try {
					$setuplog = json_decode($fileManager->fileGetContents($pathinfo));
			        } catch (pm_Exception $e) {
					$setuplog = NULL;
				} catch (Exception $e) {
					$setuplog = NULL;
			        }
		

			} while ($setuplog == NULL);

			if($setuplog == NULL){$this->_helper->json(['status' => 100]);return;}

			if($setuplog->download == 0 && $setuplog->status=="Install"){$setuplog->download=50;};
			if($setuplog->download == 0 &&$setuplog->status=="Service"){$setuplog->download=100;};
			if($setuplog->update == 0 && $setuplog->status=="Update"){$setuplog->download=100;$setuplog->update=100;};
			if($setuplog->config == 0 && $setuplog->status=="Finish"){$setuplog->update=100;$setuplog->config=50;};
			if($setuplog->status=="End"){$setuplog->download=100;$setuplog->update=100;$setuplog->config=100;};

			if((int)$setuplog->download===100){$percent+=33;}else{$percent+=round($setuplog->download / 33,1);}
			if((int)$setuplog->update===100){$percent+=34;}else{$percent+=round($setuplog->update / 34,1);}
			if((int)$setuplog->config===100){$percent+=33;}else{$percent+=round($setuplog->config / 33,1);}

		}

		$this->_helper->json(['status' => $percent]);
		return;
	}
	if($this->_getParam('terms')=="on"){
		pm_ApiCli::callSbin("FlexClamServer.exe",array("-setup"));
		Modules_FlexClamServer_Settings::Save("Job","");
		$this->_redirect('index');
	}



    }


  /**
     * Index Page - IndexStatus
     * @Show green bar status to admin account (StatusGreenBar)
     */
    public function IndexStatus(){

	$output="";

	if(Modules_FlexClamServer_Settings::Get("Job")=="Init"){
		return $output;
		return;
	}


	$msglicense="";
	$output="<div class='table-license'>";
	$output=$output."<div><b>" . pm_Locale::lmsg('MailServer'). "</b> : " . $this->MailServer . "</div>";
	if (Modules_FlexClamServer_License::IsLicenced()){if(pm_Config::get('ShowLicense')){$msglicense=pm_Locale::lmsg('AppProFull').$_SESSION[pm_Context::getModuleInfo()->name]['LicensePromo'];}else{$msglicense=pm_Locale::lmsg('AppProFull');}}else{$msglicense=pm_Locale::lmsg('AppProBasic') . " - <a href='".$this->view->getHelper('baseUrl')->moduleUrl(['action' => "upgrade"])."'>".pm_Locale::lmsg('Upgrade')."</a>";}
	$output=$output."<div><b>" . pm_Locale::lmsg('AppPro'). "</b> : " . $msglicense. "</div>";
	$output=$output. "</div>";


	return $output;

}

    public function indexAction(){  

	if ($this->Setup){
	        $this->_forward('overview');
	}else{
	        $this->_forward('install');
	}
    }



    public function overviewAction(){
       
	if (!$this->Setup){$this->_forward('install');return;}

        $this->view->list = $this->_getDomainsList();
	$this->view->stopall = [];

	if(pm_Settings::get('scan_lock',false)){

            $this->view->stopall[] = [
                'title' => $this->lmsg('Overview.Stop'),
                'description' => $this->lmsg('Overview.StopDesc'),
                'icon' => pm_Context::getBaseUrl() . "images/stop.png",
                'link' => $this->view->getHelper('baseUrl')->moduleUrl(['action' => "stop"]),
            ];
	}

    }

    public function virusAction(){
       	if (!$this->Setup){$this->_forward('install');return;}

        $this->view->list = $this->_getVirusList();

    }

    public function statsAction(){
       
	if (!$this->Setup){$this->_forward('install');return;}

	$dataDay = self::_getChartDataForDay();
	$dataHour = self::_getChartDataForHour();

	$this->view->plotDay = $dataDay[1];
	$this->view->plotHour = $dataHour[1];
	$this->view->plotDays = $dataDay[0];
	$this->view->plotHours = $dataHour[0];

    }

    public function logsAction(){  
	 $this->view->list = $this->_getLogs();
    }


    public function cleanlogsAction(){  

	pm_ApiCli::callSbin("FlexClamServer.exe",array("/plesk","/cleanlog"),1);
	$this->_redirect('index/logs');
    }


	

    private function _getChartDataForDay(){

	$data = Modules_FlexClamServer_Helper::StatsInfo("Day");

	$firstday = null;
	$statsdays = [];
	$statstotal = [];
	$statssfound = [];

	$total = 0;
	$found = 0;

	if(count($data)>0){$firstday=$data[array_key_first($data)]["day"];}else{$firstday=date("Y-m-d");}

	for($ic=(30-count($data));$ic>0;$ic--){

		$statsdays[] = date('Y-m-d', strtotime("-". $ic." day", strtotime($firstday)));
		$statstotal[] = 0;
		$statssfound[] = 0;

	}

	foreach ($data as $day){

		$statsdays[] = $day["day"];
		$statstotal[] = (integer)$day["total"];
		$statssfound[] = (integer)$day["found"];

		$total += $day["total"];
		$found += $day["found"];

	}


        $dataplot = [];

	$dataplot[] = array(
		'x'         => $statsdays,
		'y'         => $statstotal,
        	'name'      => $this->lmsg('Stats.Total') . " : " .Modules_FlexClamServer_Helper::StyleCount($total),
	        'type'      => 'bar',
        );


	$dataplot[] = array(
		'x'         => $statsdays,
		'y'         => $statssfound,
        	'name'      => $this->lmsg('Stats.Found') . " : " . Modules_FlexClamServer_Helper::StyleCount($found),
	        'type'      => 'bar',
        );



	return [count($data),$dataplot];

    }

    private function _getChartDataForHour(){

	$data = Modules_FlexClamServer_Helper::StatsInfo("Hour");

	$firsthour = null;
	$statshour = [];
	$statstotal = [];
	$statssfound = [];

	$total = 0;
	$found = 0;
	$ihour = 1;

	if(count($data)>0){$firsthour=$data[array_key_first($data)]["hour"];}else{$firsthour=date("Y-m-d H:00");}

	for($ic=(24-count($data));$ic>0;$ic--){

		$statshour[] = date('Y-m-d', strtotime("-". $ic." hour", strtotime($firsthour)));
		$statstotal[] = 0;
		$statssfound[] = 0;

	}

	foreach ($data as $day){
		if($ihour>24){break;}

		$statshour[] = $day["hour"];
		$statstotal[] = (integer)$day["total"];
		$statssfound[] = (integer)$day["found"];

		$total += $day["total"];
		$found += $day["found"];

		$ihour++;

	}


        $dataplot = [];

	$dataplot[] = array(
		'x'         => $statshour,
		'y'         => $statstotal,
        	'name'      => $this->lmsg('Stats.Total') . " : " . Modules_FlexClamServer_Helper::StyleCount($total),
	        'type'      => 'bar',
        );


	$dataplot[] = array(
		'x'         => $statshour,
		'y'         => $statssfound,
        	'name'      => $this->lmsg('Stats.Found') . " : " . Modules_FlexClamServer_Helper::StyleCount($found),
	        'type'      => 'bar',

        );



	return [$ihour-1,$dataplot];

    }


    private function _getVirusList(){

	$data = [];
	$fileManager = new pm_ServerFileManager();
	$filePath = pm_Context::getVarDir() . "\\Virus.cfg";

	if ($fileManager->fileExists($filePath)) {
		$icount = 0;
		$listContent = explode(PHP_EOL,$fileManager->fileGetContents($filePath));


	        $stateClean[] = pm_Context::getBaseUrl() . 'images/on.png';
	        $stateClean[] = pm_Context::getBaseUrl() . 'images/bug.png';

		$stateAlt[] = $this->lmsg('Virus.Protect');
		$stateAlt[] = $this->lmsg('Virus.Found');

		foreach ((array)$listContent as $info) {
			if(Modules_FlexClamServer_Settings::GetLength($info)<1){continue;}
			$columns = explode("\t",$info);

			$typeFile = $this->lmsg('Virus.Type'.$columns[1]);
			$fileLink = "<img src=\"" . pm_Context::getBaseUrl() . "images/file.png\" title=\"" . htmlspecialchars($stateAlt[$columns[4]], ENT_QUOTES) . "\"> ". $columns[2];
			if($columns[1] == "Email"){
				$details = "<b>" . str_replace(";",";<b>",str_replace(" : "," :</b> ",str_replace("}","",str_replace("{","",str_replace(">","&gt&",str_replace("<","&lt&",$columns[5]))))));
				$detailsItems = explode(";",$details);
				$email = str_replace("<b>To :</b> ","",$detailsItems[1]);

				$fileLink = "<a href=\"#\" onclick=\"new Jsw.Popup({'title':'<img src=\'" . pm_Context::getBaseUrl() . "images/mail.png\'> " . $email . "','content':'" .htmlspecialchars(str_replace("&gt&","&gt;",str_replace("&lt&","&lt;",str_replace(";","<br>",$details))), ENT_QUOTES). "',closeButtonEnabled:true})\"><img src=\"" . pm_Context::getBaseUrl() . "images/mail.png\" title=\"" . htmlspecialchars($this->lmsg('Logs.Info'), ENT_QUOTES) . "\"></a> ". $email;

			}


			if($columns[4]==7){$columns[4]=0;}
			if($columns[4]==999){$columns[4]=1;}
			if($columns[4]==6){$columns[4]=1;}

			$colCleanState = '<img src="' .  $stateClean[$columns[4]] . '" title="' . $this->lmsg('Virus.Name') . '"> ';

			$data[] = ["id" => $icount, "date" => Modules_FlexClamServer_Settings::FormatDateOutput($columns[0],$this->lmsg('formatDate') . " hh:mm"), "type" => $typeFile, "virus" => $colCleanState . $columns[3], "file" => $fileLink ];
			$icount++;
		}


	}

 	if (count($data) < 1) {
            return new pm_View_List_Simple($this->view, $this->_request);
        }

    	$options = [
            'defaultSortField' => 'column-1',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_DOWN,
        ];
        $list = new pm_View_List_Simple($this->view, $this->_request, $options);
        $list->setData($data);
        $list->setColumns([
            pm_View_List_Simple::COLUMN_SELECTION,
            'date' => [
                'title' => $this->lmsg('Virus.Date'),
                'noEscape' => true,
                'searchable' => false,
                'sortable' => true,
            ],
            'type' => [
                'title' => $this->lmsg('Virus.Type'),
                'noEscape' => true,
                'searchable' => false,
                'sortable' => true,
            ],
            'virus' => [
                'title' => $this->lmsg('Virus.Name'),
                'noEscape' => true,
                'searchable' => true,
                'sortable' => true,
            ],
            'file' => [
                'title' => $this->lmsg('Virus.File'),
                'noEscape' => true,
                'sortable' => true,
            ],
        ]);

        $listTools = [];

        $listTools[] = [
            'title' => $this->lmsg('Virus.Scan'),
            'description' => $this->lmsg('Virus.ScanDesc'),
            'class' => 'sb-scan bt-clickwait',
            'execGroupOperation' => $this->_helper->url('scan'),
        ];

        $listTools[] = [
            'title' => $this->lmsg('Virus.Delete'),
            'description' => $this->lmsg('Virus.DeleteDesc'),
            'class' => 'sb-delete bt-clickwait',
            'execGroupOperation' => $this->_helper->url('delete'),
        ];

        $listTools[] = [
            'title' => $this->lmsg('Virus.Clean'),
            'description' => $this->lmsg('Virus.CleanDesc'),
            'class' => 'sb-clean bt-clickwait',
            'execGroupOperation' => $this->_helper->url('clean'),
        ];

        $list->setTools($listTools);
        $list->setDataUrl(['action' => 'virus-data']);

        return $list;


    }

    private function _getLogs(){

	$data = [];
	$result = pm_ApiCli::callSbin("FlexClamServer.exe",array("/plesk","/log","-json"),1);
	$jsonlog=str_replace(PHP_EOL,"<br>",str_replace("\n","<br>",$result['stdout']));
	$json = json_decode($jsonlog);

	foreach ((array)$json->logs as $info) {


		$icon="<img src=\"". pm_Context::getBaseUrl() ."images/info.png\" title=\"".$this->lmsg('Logs.Type'.$info->level)."\"> ";
		if($info->id=='1'){$icon="<img src=\"". pm_Context::getBaseUrl() ."images/scan.png\" loading=\"lazy\" title=\"".$this->lmsg('Logs.Type'.$info->level)."\"> ";}
		if($info->id=='2'){$icon="<img src=\"". pm_Context::getBaseUrl() ."images/bug.png\" loading=\"lazy\" title=\"".$this->lmsg('Logs.Type'.$info->level)."\"> ";}
		if($info->id=='3'){$icon="<img src=\"". pm_Context::getBaseUrl() ."images/bad.png\" loading=\"lazy\" title=\"".$this->lmsg('Logs.Type'.$info->level)."\"> ";}
		if($info->id=='5' || $info->id=='6'){$icon="<img src=\"". pm_Context::getBaseUrl() ."images/debug.png\" loading=\"lazy\" title=\"".$this->lmsg('Logs.Type'.$info->level)."\"> ";}

		$desc = $icon;
		if(strpos($info->info,"Flex Clam Server")!==false){$desc = "<img src=\"". pm_Context::getBaseUrl() ."images/logo.png\" title=\"Flex Clam Server\"> <b>".$info->info. "</b>";}else{$desc = $desc . " " . $info->info;}

		$data[] = ["date" => $info->date , "info" =>$desc];
	}


 	if (count($data) < 1) {
            return new pm_View_List_Simple($this->view, $this->_request);
        }

    	$options = [
            'defaultSortField' => 'column-1',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_DOWN,
        ];
        $list = new pm_View_List_Simple($this->view, $this->_request, $options);
        $list->setData($data);
        $list->setColumns([
            'date' => [
                'title' => $this->lmsg('Logs.Date'),
                'noEscape' => true,
                'searchable' => true,
                'sortable' => true,
            ],
            'info' => [
                'title' => $this->lmsg('Logs.Info'),
                'noEscape' => true,
                'sortable' => true,
            ],
        ]);


        $list->setTools([[
                'title' => pm_Locale::lmsg('Logs.Clean'),
                'class' => 'sb-clean bt-clickwait',
                'action' => "cleanlogs",
                'data-loading' => "true",
		'description' => pm_Locale::lmsg('Logs.Clean'),
            ]
        ]);

        $list->setDataUrl(['action' => 'logs-data']);

        return $list;


    }

    private function _getDomainsList(){
        $data = [];
        $Domainlist = Modules_FlexClamServer_Helper::GetAllDomains();

        foreach ($Domainlist as $domain) {

            $stateEnableSrc = pm_Context::getBaseUrl() . 'images/on.png';
	    $stateEnableAlt = $this->lmsg('Status-On');
	    if(!$domain['enable']){$stateEnableSrc = pm_Context::getBaseUrl() . 'images/off.png'; $stateEnableAlt = $this->lmsg('Status-Off');}
	    if($domain['scanning']){$stateEnableSrc = pm_Context::getBaseUrl() . 'images/indicator.gif'; $stateEnableAlt = $this->lmsg('Scan.Running');}

            $stateStatusSrc = pm_Context::getBaseUrl() . 'images/domain.png';
	    if($domain['status']=="Off"){$stateStatusSrc = pm_Context::getBaseUrl() . 'images/off.png';}
            $stateImgAlt = $this->lmsg('Host-'.$domain['status']);

            $colScanningState = '<img src="' . $stateStatusSrc . '" title="' . htmlspecialchars($stateImgAlt, ENT_QUOTES) . '">';
            $colDomain = $colScanningState . ' <a target="_blank" href="/admin/subscription/login/id/' . $domain['suscription'] . '?pageUrl=/smb/web/overview/id/'.$domain['id'].'/type/domain">' . $domain['name'] . '</a>';

            $data[] = [
		'id' => $domain['scanning'] ? 'disabled' : $domain['id'],
                'column-1' => '<img src="' . $stateEnableSrc . '" title="' . htmlspecialchars($stateEnableAlt, ENT_QUOTES) . '"> ' . $stateEnableAlt,
                'column-2' => $colDomain,
                'column-3' => Modules_FlexClamServer_Helper::StyleSize($domain['hostSize']),
                'column-4' => $domain['lastScan']==null ? $this->lmsg('Overview.NerverScan') : Modules_FlexClamServer_Settings::FormatDateOutput($domain['lastScan'],$this->lmsg('formatDate') . " hh:mm") ,
                'column-5' => $domain['warnings']
            ];

        }
        
 	if (count($data) < 1) {
            return new pm_View_List_Simple($this->view, $this->_request);
        }
        
        $options = [
            'defaultSortField' => 'column-2',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_DOWN,
        ];
        $list = new pm_View_List_Simple($this->view, $this->_request, $options);
        $list->setData($data);
        $list->setColumns([
            pm_View_List_Simple::COLUMN_SELECTION,
            'column-1' => [
                'title' => $this->lmsg('Overview.AutoScan'),
                'noEscape' => true,
                'searchable' => false,
                'sortable' => true,
            ],
            'column-2' => [
                'title' => $this->lmsg('Overview.Domain'),
                'noEscape' => true,
                'searchable' => true,
                'sortable' => true,
            ],
            'column-3' => [
                'title' => $this->lmsg('Overview.HostSize'),
                'noEscape' => true,
                'searchable' => true,
                'sortable' => true,
            ],
            'column-4' => [
                'title' => $this->lmsg('Overview.LastScan'),
                'sortable' => true,
            ],
            'column-5' => [
                'title' => $this->lmsg('Overview.Warnings'),
                'sortable' => true,
            ],

        ]);

        $listTools = [];


        $listTools[] = [
                    'title' => $this->lmsg('Overview.ScanHost'),
                    'description' => $this->lmsg('Overview.ScanHostDesc'),
                    'class' => "sb-scan bt-clickwait",
                    'execGroupOperation' => $this->_helper->url("start"),
        ];

        $listTools[] = [
            'title' => $this->lmsg('Overview.Enable'),
            'description' => $this->lmsg('Overview.EnableDesc'),
            'class' => 'sb-make-visible',
            'execGroupOperation' => $this->_helper->url('enable'),
        ];
        $listTools[] = [
            'title' => $this->lmsg('Overview.Disable'),
            'description' => $this->lmsg('Overview.DisableDesc'),
            'class' => 'sb-make-invisible',
            'execGroupOperation' => $this->_helper->url('disable'),
        ];

        $list->setTools($listTools);

        $list->setDataUrl(['action' => 'overview-data']);

        return $list;
    }


    public function logsDataAction(){  
	$list = $this->_getLogs();
        $this->_helper->json($list->fetchData());
    }
    public function overviewDataAction(){
        $list = $this->_getDomainsList();
        $this->_helper->json($list->fetchData());
    }
    public function virusDataAction(){  
	$list = $this->_getVirusList();
        $this->_helper->json($list->fetchData());
    }

    public function alertDataAction(){  
	$showAll = $this->_getParam('show') == '1' ? true : false;
        $list = $this->_getAlertList($showAll)[1];
        $this->_helper->json($list->fetchData());
    }


    /**
     * Upgrade Page License
     */
    public function upgradeAction(){

    }

   public function enableAction(){
        foreach ((array)$this->_getParam('ids') as $domainId) {
		pm_Domain::getByDomainId($domainId)->setSetting("enable",true);
	}

        $messages[] = ['status' => 'info', 'content' => $this->lmsg('Overview.EnableSuccess')];
        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);
    }

    public function disableAction(){
        foreach ((array)$this->_getParam('ids') as $domainId) {
		pm_Domain::getByDomainId($domainId)->setSetting("enable",false);
	}
        $messages[] = ['status' => 'info', 'content' => $this->lmsg('Overview.DisableSuccess')];
        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);
    }


    public function scanAction(){

	pm_ApiCli::callSbin("FlexClamServer.exe",array("-virus","-scan",implode(",",(array)$this->_getParam('ids'))),1);

        $this->view->status->addInfo($this->lmsg('Virus.ScanSuccess'));
        $this->_redirect('virus');
    }

    public function wdAction(){

	$this->WD = false;
	unset($_SESSION[pm_Context::getModuleInfo()->name]['Activity']);

	if($this->_getParam('do')=="1"){
		pm_ApiCli::callSbin("FlexClamServer.exe",array("-WD","-enable"),1);
	}else{
		pm_ApiCli::callSbin("FlexClamServer.exe",array("-WD","-disable"),1);
	}

        $this->view->status->addInfo($this->lmsg('Settings.ApplySuccess'));
        $this->_redirect('index');
    }

    public function wdfilterAction(){

	$this->MEFilterFlex = false;
	unset($_SESSION[pm_Context::getModuleInfo()->name]['Activity']);

	if($this->_getParam('do')=="1"){
		pm_ApiCli::callSbin("FlexClamServer.exe",array("-WD","-enable","-filter"),1);
	}else{
		pm_ApiCli::callSbin("FlexClamServer.exe",array("-WD","-disable","-filter"),1);
	}

        $this->view->status->addInfo($this->lmsg('Settings.ApplySuccess'));
        $this->_redirect('index');
    }

    public function clfilterAction(){

	$this->MEFilterFlex = true;
	unset($_SESSION[pm_Context::getModuleInfo()->name]['Activity']);

	pm_ApiCli::callSbin("FlexClamServer.exe",array("-CL","-enable","-filter"),1);

        $this->view->status->addInfo($this->lmsg('Settings.ApplySuccess'));
        $this->_redirect('index');
    }

    public function deleteAction(){

	pm_ApiCli::callSbin("FlexClamServer.exe",array("-virus","-remove",implode(",",(array)$this->_getParam('ids'))),1);

        $this->view->status->addInfo($this->lmsg('Virus.DeleteSuccess'));
        $this->_redirect('virus');
    }


    public function cleanAction(){

	pm_ApiCli::callSbin("FlexClamServer.exe",array("-virus","-clean",implode(",",(array)$this->_getParam('ids'))),1);

        $this->view->status->addInfo($this->lmsg('Virus.CleanSuccess'));
        $this->_redirect('virus');
    }

    public function autoscanAction(){

	Modules_FlexClamServer_Settings::Save("EnableAutoScan", "1");

        $this->view->status->addInfo($this->lmsg('Settings.SaveSuccess'));
        $this->_redirect(pm_Context::getBaseUrl());
    }

    public function runAction(){

	unset($_SESSION[pm_Context::getModuleInfo()->name]['Activity']);

	Modules_FlexClamServer_Settings::Save("EnableAutoScan", "1");
	pm_ApiCli::callSbin("FlexClamServer.exe",array("/plesk","/run"),1);
	sleep(3);
        $this->view->status->addInfo($this->lmsg('Settings.SaveSuccess'));
        $this->_redirect(pm_Context::getBaseUrl());
    }

    public function mailAction(){

	if($this->_getParam('id')!=null){
		$this->_helper->json(['running' => Modules_FlexClamServer_Check::TaskRunning($this->_getParam('id')) ]);
		return;
	}

	$taskManager = new pm_LongTask_Manager();
	$scanTask = new Modules_FlexClamServer_Task_Mail();
        $scanTask->setParams(['domain' => $this->_getParam('domain')]);
        $scanTask->setParams(['name' => $this->_getParam('name')]);
	$scanTask->setParams(['remove' => "0"]);
       	$GetTask = $taskManager->start($scanTask);

	sleep(1);

	$_SESSION[pm_Context::getModuleInfo()->name][$this->_getParam('name')."@".$this->_getParam('domain')]="0";
	$this->_helper->json(['domain' => $this->_getParam('domain'),'name' => $this->_getParam('name') , 'idTask' => $GetTask->getInstanceId() ]);

    }

    public function startAction(){

        foreach ((array)$this->_getParam('ids') as $domainId) {

		$taskManager = new pm_LongTask_Manager();
		$scanTask = new Modules_FlexClamServer_Task_Scan();
	        $scanTask->setParams(['domainId' => $domainId]);
		$scanTask->setParams(['remove' => "0"]);
        	$taskManager->start($scanTask);

		sleep(1);

	}

        $this->view->status->addInfo($this->lmsg('Overview.StartSuccess'));
        $this->_redirect(pm_Context::getBaseUrl());
    }


    public function stopAction(){

        $taskManager = new pm_LongTask_Manager();
	$taskManager->cancelAllTasks();

	pm_Settings::set('scan_lock',0);

	pm_ApiCli::callSbin("FlexClamServer.exe",array("-task","-stop"),1);

	 foreach ((array)Modules_FlexClamServer_Helper::GetAllDomains() as $domain) {

		if(filter_var(pm_Domain::getByDomainId($domain["id"])->getSetting("scanning",false), FILTER_VALIDATE_BOOLEAN)){Modules_FlexClamServer_Check::Stop($domain["id"]);}	
	}


        $this->view->status->addInfo($this->lmsg('Overview.StopSuccess'));
        $this->_redirect(pm_Context::getBaseUrl());
    }

    public function cancelAction(){

        $task = Modules_FlexClamServer_Check::Task($this->_getParam('task'));
	if($task!=null){
	        $taskManager = new pm_LongTask_Manager();
		Modules_FlexClamServer_Check::Stop($task->getParam("domainId"));
		$taskManager->cancel($task);
	}

        $this->_redirect(pm_Context::getBaseUrl());
    }

    
    public function settingsAction(){

	if (!$this->Setup){$this->_forward('install');return;}

        $form = new Modules_FlexClamServer_Form_Settings(['isLicensed' => $this->Licensed]);

        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            try {

		$result=$form->process();
                $this->_status->addMessage('info', $this->lmsg('Settings.SaveSuccess'));
         

            } catch (pm_Exception $e) {
		$this->_helper->json(array('status' => 'danger','msg' => $e->getMessage()));
            }

	    unset($_SESSION[pm_Context::getModuleInfo()->name]['Activity']);
	    $this->_redirect('settings');
	    return;

        }

	$this->view->Status=self::IndexStatus();
        $this->view->form = $form;
    }

 
}
