<?php
/**
 * Copyright 2025 Flex Clam Server for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2025 Flex Clam Server for Plesk
 * @author Flex Antivirus <info@antivirus.flexservices.app>
 * @license Copyright
 */

class ToolsController extends pm_Controller_Action{


    private $Licensed = false;


    public function __call($name, $arguments){
 		$this->_status->addMessage('warning','Not Found');
                $this->_redirect('index?call'.$name, [ 'exit' => true ]);
                return;
    }

    public function init(){

        $this->_accessLevel = 'admin';
        
        parent::init();
	$this->Setup = (Modules_FlexClamServer_Settings::Get("Job")=="Init" ? false : true);

       
	$this->view->pageTitle = $this->lmsg('pageTitle');
	$this->view->headLink()->appendStylesheet(pm_Context::getBaseUrl() . 'flex-clam-server.css?'.Date('dmhYis'));
	$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'js/ext-flex-clam-server-library.js?'.Date('dmhYis'));
	$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'js/ext-flex-clam-server-init.js?'.Date('dmhYis'));


	if ($this->Setup){


		if(!pm_Config::get('ShowLicense') && !isset($_SESSION[pm_Context::getModuleInfo()->name]['InitInfo'])){$this->_status->addMessage('info', pm_Locale::lmsg('InitInfo'));$_SESSION[pm_Context::getModuleInfo()->name]['InitInfo']=1;}

        
		$selectab = $this->getRequest()->getParam('action');

        	$this->view->tabs = [
	            [
        	        'title' => $this->lmsg('tabOverview'),
			'controller' => 'index',
                	'action' => 'overview',
	            ],
        	    [
                	'title' => $this->lmsg('tabVirus'),
			'controller' => 'index',
	                'action' => 'virus',
	            ],
        	    [
                	'title' => $this->lmsg('tabTools'),
	                'action' => 'tools',
        	        'containerCls' => ($selectab=='tools' || $selectab=='alert' || $selectab=='optimize' ? 'active' : ''),
        	    ],
	            [
        	        'title' => $this->lmsg('tabStats'),
			'controller' => 'index',
                	'action' => 'stats',
	            ],
        	    [
                	'title' => $this->lmsg('tabSettings'),
			'controller' => 'index',
	                'action' => 'settings',
	            ],
        	    [
                	'title' => $this->lmsg('tabLogs'),
			'controller' => 'index',
	                'action' => 'logs',
        	    ],
	        ];

        	$this->view->toolsSubtabs = [
	            [
        	        'title' => $this->lmsg('tabAlert'),
                	'action' => 'alert',
	            ],
        	    [
                	'title' => $this->lmsg('tabOptimize'),
	                'action' => 'optimize',
	            ],
        	    [
                	'title' => "Firewall",
	                'action' => 'firewall',
	            ],
	        ];

		$this->Licensed = Modules_FlexClamServer_License::isLicenced();

    	}else{
		  $this->_redirect(pm_Context::getBaseUrl());
		  return;
	}

    }


    public function indexAction(){  

        $this->_forward('alert');

    }

    public function firewallAction(){

	if(Modules_FlexClamServer_Helper::ExtExist("flex-firewall-manager")){
		$this->_redirect("../../flex-firewall-manager/?context=extFlexClamServer");
		return;
	}

    }


    public function optimizeAction(){


	if( $this->_getParam('do')!=null ){
		$result = pm_ApiCli::callSbin("FlexClamServer.exe",array("/computer","/".$this->_getParam('do'),"-json"),1);
		$this->_helper->json(json_decode($result['stdout']));
	}else{
		if(!$this->Licensed){pm_View_Status::addWarning($this->lmsg('Noti.UpgradePRO'),true);}
	}

    }

    public function alertAction(){


	if(!$this->Licensed){pm_View_Status::addWarning($this->lmsg('Noti.UpgradePRO'),true);}

	if(!empty($this->_getParam('scan')) && $this->_getParam('scan')=="system"){if($this->Licensed){pm_ApiCli::callSbin("FlexClamServer.exe",array("-alert","-scan"),1);}sleep(1);$this->_redirect('tools/alert/view/'.$this->_getParam('view'));return;}
        if(!empty($this->_getParam('fix'))){if($this->Licensed){pm_ApiCli::callSbin("FlexClamServer.exe",array("-alert","-fix",$this->_getParam('fix')),1);}sleep(1);$this->_redirect('tools/alert/view/0');return;}

	$showAll = $this->_getParam('view') == '1' ? true : false;
	$infoAlert = $this->_getAlertList($showAll);

	$date = $infoAlert[0];

	$this->view->date = ($date==null ? null : Modules_FlexClamServer_Settings::FormatDateOutput(gmdate("Y-m-d H:i:s", $date),$this->lmsg('formatDate') . " hh:mm"));
        $this->view->list = $infoAlert[1];
	$this->view->showAll = $showAll;
	$this->view->smallTools = [];


	if( $this->view->date == null || gmdate("Y-m-d H:i:s", $date) < gmdate('Y-m-d H:i:s', strtotime('-20 minute')) ){
	  	$this->view->smallTools[] = [
            		'title' => $this->lmsg('Alert.Scan'),
	            	'description' => $this->lmsg('Alert.ScanDesc'),
        	    	'class' => 'sb-scan bt-clickwait',
            		'link' => $this->_helper->url('alert/scan/system/view/'. ($showAll ? '1' : '0') )
        	];
	}

    }



    private function _getAlertList($showAll = false){

	$scandate = null;
	$data = [];
	$fileManager = new pm_ServerFileManager();
	$filePath = pm_Context::getVarDir() . "\\Alert.cfg";

	if ($fileManager->fileExists($filePath)) {

		$flexFirewall = Modules_FlexClamServer_Helper::ExtExist("flex-firewall-manager");

		$imgTemplate = "<img src=\"" . pm_Context::getBaseUrl() . "images/%1%\" title=\"%2%\"> %3%";

		$json = json_decode($fileManager->fileGetContents($filePath));

		$scandate = $json->scandate;

		if($json->updates->status){

			if($showAll){
			$data[] = [
				"type" => "system-updates",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon("OK") . "&nbsp;" . str_replace("%3%","<b>".pm_Locale::lmsg('Alert.SystemUpdate')."</b>",str_replace("%2%",pm_Locale::lmsg('Alert.TypeSystem'),str_replace("%1%","refresh.png",$imgTemplate))),
				"client" => pm_Locale::lmsg('Alert.TypeSystem'),
				"domain" => "",
				"info" => "",
				"status" => "OK",
				"action" => ""
			];
			}
		}else{
			$info = "";
			if($json->updates->Setting){$info = $info . "<span class=\"info-alert-msg-item\"><span class=\"pul-label pul-label--info pul-label--caps\"><span class=\"pul-label__content\">" . pm_Locale::lmsg('Alert.UpdateSetting'). "</span></span></span>";}
			if($json->updates->System){$info = $info . "<span class=\"info-alert-msg-item\"><span class=\"pul-label pul-label--info pul-label--caps\"><span class=\"pul-label__content\">" . pm_Locale::lmsg('Alert.UpdateSystem'). "</span></span></span>";}

			$data[] = [
				"type" => "system-updates",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon("ERROR") . "&nbsp;" . str_replace("%3%","<b>".pm_Locale::lmsg('Alert.SystemUpdate')."</b>",str_replace("%2%",pm_Locale::lmsg('Alert.TypeSystem'),str_replace("%1%","refresh.png",$imgTemplate))),
				"client" => pm_Locale::lmsg('Alert.TypeSystem'),
				"domain" => "",
				"info" => $info,
				"status" => "BAD",
				"action" => ""
			];
		}

		if($showAll || $json->mime->vbs){
			$info = "";

			$data[] = [
				"type" => "mime-vbs",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon(($json->mime->vbs ? "ERROR" : "OK")) . "&nbsp;" . str_replace("%3%","<b>".pm_Locale::lmsg('Alert.MimeVBS')."</b>",str_replace("%2%",pm_Locale::lmsg('Alert.TypeSystem'),str_replace("%1%","file.png",$imgTemplate))),
				"client" => pm_Locale::lmsg('Alert.TypeSystem'),
				"domain" => "",
				"info" => "",
				"status" => ($json->mime->vbs ? "BAD" : "OK"),
				"action" => ($json->mime->vbs ? "<ul class=\"pul-button-group\"  data-class=\"pul-button--ghost pul-button--empty\" data-svg=\"dots3\" style=\"display:none\"><li data-svg=\"fixit\"><a href=\"".pm_Context::getBaseUrl()."/index.php/tools/alert/fix/vbs\">".pm_Locale::lmsg('Action.Fix')."</a></li></ul>" : "")
			];

		}

		$urlSetup = "/modules/catalog/index.php/installed/flex-firewall-manager";
		$urlGo = "/modules/flex-firewall-manager/index.php/index/index?context=extflexclamserver";
		$urlGoSSL = "/modules/flex-firewall-manager/index.php/index/web?context=extflexclamserver";
		$urlGoRemote = "/modules/flex-firewall-manager/index.php/index/firewall?context=extflexclamserver";


		$installAction="<li data-svg=\"setting\" data-maxwidth=\"180\"><a href=\"".$urlSetup."\">".pm_Locale::lmsg('Alert.FlexFirewallInstall')."</a></li>";
		$goAction="<li data-svg=\"setting\"><a href=\"".$urlGo."\">".pm_Locale::lmsg('Alert.FlexFirewallGo')."</a></li>";
		$goSSLAction="<li data-svg=\"setting\"><a href=\"".$urlGoSSL."\">".pm_Locale::lmsg('Alert.FlexFirewallGo')."</a></li>";
		$goRemoteAction="<li data-svg=\"setting\"><a href=\"".$urlGoRemote."\">".pm_Locale::lmsg('Alert.FlexFirewallGo')."</a></li>";
		$notiAction="<li data-svg=\"mail\"><a href=\"%1\">".pm_Locale::lmsg('Action.Noti')."</a></li>";
		$forceAction="<li data-svg=\"timereload\"><a href=\"%1\">".pm_Locale::lmsg('Action.Force')."</a></li>";

		if($json->firewall->status){

			if($json->firewall->FlexFirewall){
				if($showAll){
					$data[] = [
						"type" => "system-firewall",
						"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon("OK") . "&nbsp;" . str_replace("%3%","<b>".pm_Locale::lmsg('Alert.SystemFirewall')."</b>",str_replace("%2%",pm_Locale::lmsg('Alert.TypeSystem'),str_replace("%1%","firewall.png",$imgTemplate))),
						"client" => pm_Locale::lmsg('Alert.TypeSystem'),
						"domain" => "",
						"info" => "<a href='".$urlGo."' class='s-btn sb-login'>" . pm_Locale::lmsg('Alert.FirewallFlex'). "</a>",
						"status" => "OK",
						"action" => ""
					];
				}
			}else{

				$info = "";
				if(!$json->firewall->WindowsDefender){$info = $info . "<span class=\"info-alert-msg-item\"><span class=\"pul-label pul-label--warning pul-label--caps\"><span class=\"pul-label__content\">" . pm_Locale::lmsg('Alert.FirewallWindows') . "</span></span></span>";}

				$data[] = [
					"type" => "system-firewall",
					"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon("ERROR") . "&nbsp;" . str_replace("%3%","<b>".pm_Locale::lmsg('Alert.SystemFirewall')."</b>",str_replace("%2%",pm_Locale::lmsg('Alert.TypeSystem'),str_replace("%1%","firewall.png",$imgTemplate))),
					"client" => pm_Locale::lmsg('Alert.TypeSystem'),
					"domain" => "",
					"info" => $info,
					"status" => "OLD",
					"action" => "<ul class=\"pul-button-group\"  data-class=\"pul-button--ghost pul-button--empty\" data-svg=\"dots3\" style=\"display:none\">".($flexFirewall ? $goAction : $installAction)."</ul>"
				];
			}
		}else{

			$info = "";
			if(!$json->firewall->FlexFirewall && !$json->firewall->WindowsDefender){$info = $info . "<span class=\"info-alert-msg-item\"><span class=\"pul-label pul-label--danger pul-label--caps\"><span class=\"pul-label__content\">" . pm_Locale::lmsg('Alert.FirewallKO') . "</span></span></span>";}

			$data[] = [
				"type" => "system-firewall",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon("BAD",pm_Locale::lmsg('Alert.StatusCHK')) . "&nbsp;" . str_replace("%3%","<b>".pm_Locale::lmsg('Alert.SystemFirewall')."</b>",str_replace("%2%",pm_Locale::lmsg('Alert.TypeSystem'),str_replace("%1%","firewall.png",$imgTemplate))),
				"client" => pm_Locale::lmsg('Alert.TypeSystem'),
				"domain" => "",
				"info" => $info,
				"status" => "BAD",
				"action" => "<ul class=\"pul-button-group\"  data-class=\"pul-button--ghost pul-button--empty\" data-svg=\"dots3\" style=\"display:none\">".($flexFirewall ? $goAction : $installAction)."</ul>"
			];
		}


		if($showAll || $json->cipher->old){

			$data[] = [
				"type" => "system-tls",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon(($json->cipher->old ? "BAD" : "OK")) . "&nbsp;" . str_replace("%3%","<b>".pm_Locale::lmsg('Alert.SystemTLS')." SSL</b>",str_replace("%2%",pm_Locale::lmsg('Alert.TypeSystem'),str_replace("%1%","ssl.png",$imgTemplate))),
				"client" => pm_Locale::lmsg('Alert.TypeSystem'),
				"domain" => "",
				"info" => ($json->cipher->old ? "<span class=\"info-alert-msg-item\"><span class=\"pul-label pul-label--danger pul-label--caps\"><span class=\"pul-label__content\">" .pm_Locale::lmsg('Alert.SSLOLD'). "</span></span></span>" : pm_Locale::lmsg('Alert.DisableTLS')),
				"status" => ($json->cipher->old ? "BAD" : "OK"),
				"action" =>  ($json->cipher->old ? "<ul class=\"pul-button-group\"  data-class=\"pul-button--ghost pul-button--empty\" data-svg=\"dots3\" style=\"display:none\">".($flexFirewall ? $goSSLAction : $installAction)."</ul>" : "")
			];
		}

		if($showAll || $json->cipher->tls10){
			$data[] = [
				"type" => "system-tls",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon(($json->cipher->tls10 ? "BAD" : "OK")) . "&nbsp;" . str_replace("%3%","<b>".pm_Locale::lmsg('Alert.SystemTLS')." TLS 1.0</b>",str_replace("%2%",pm_Locale::lmsg('Alert.TypeSystem'),str_replace("%1%","ssl.png",$imgTemplate))),
				"client" => pm_Locale::lmsg('Alert.TypeSystem'),
				"domain" => "",
				"info" => ($json->cipher->tls10 ? "<span class=\"info-alert-msg-item\"><span class=\"pul-label pul-label--danger pul-label--caps\"><span class=\"pul-label__content\">" .pm_Locale::lmsg('Alert.SSLBAD'). "</span></span></span>" : pm_Locale::lmsg('Alert.DisableTLS')),
				"status" => ($json->cipher->tls10 ? "BAD" : "OK"),
				"action" =>  ($json->cipher->tls10 ? "<ul class=\"pul-button-group\"  data-class=\"pul-button--ghost pul-button--empty\" data-svg=\"dots3\" style=\"display:none\">".($flexFirewall ? $goSSLAction : $installAction)."</ul>" : "")
			];
		}
		if($showAll || $json->cipher->tls11){
			$data[] = [
				"type" => "system-tls",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon(($json->cipher->tls11 ? "BAD" : "OK")) . "&nbsp;" . str_replace("%3%","<b>".pm_Locale::lmsg('Alert.SystemTLS')." TLS 1.1</b>",str_replace("%2%",pm_Locale::lmsg('Alert.TypeSystem'),str_replace("%1%","ssl.png",$imgTemplate))),
				"client" => pm_Locale::lmsg('Alert.TypeSystem'),
				"domain" => "",
				"info" => ($json->cipher->tls11 ? "<span class=\"info-alert-msg-item\"><span class=\"pul-label pul-label--danger pul-label--caps\"><span class=\"pul-label__content\">" .pm_Locale::lmsg('Alert.SSLBAD'). "</span></span></span>" : pm_Locale::lmsg('Alert.DisableTLS')),
				"status" => ($json->cipher->tls11 ? "BAD" : "OK"),
				"action" =>  ($json->cipher->tls11 ? "<ul class=\"pul-button-group\"  data-class=\"pul-button--ghost pul-button--empty\" data-svg=\"dots3\" style=\"display:none\">".($flexFirewall ? $goSSLAction : $installAction)."</ul>" : "")
			];
		}
		if($showAll || !$json->cipher->tls12){
			$data[] = [
				"type" => "system-tls",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon((!$json->cipher->tls12 ? "ERROR" : "OK")) . "&nbsp;" . str_replace("%3%","<b>".pm_Locale::lmsg('Alert.SystemTLS')." TLS 1.2</b>",str_replace("%2%",pm_Locale::lmsg('Alert.TypeSystem'),str_replace("%1%","ssl.png",$imgTemplate))),
				"client" => pm_Locale::lmsg('Alert.TypeSystem'),
				"domain" => "",
				"info" => (!$json->cipher->tls12 ? "<span class=\"info-alert-msg-item\"><span class=\"pul-label pul-label--warning pul-label--caps\"><span class=\"pul-label__content\">" .pm_Locale::lmsg('Alert.SSLOK'). "</span></span></span>"  : pm_Locale::lmsg('Alert.EnableTLS')),
				"status" => (!$json->cipher->tls12 ? "BAD" : "ERROR"),
				"action" =>  (!$json->cipher->tls12 ? "<ul class=\"pul-button-group\"  data-class=\"pul-button--ghost pul-button--empty\" data-svg=\"dots3\" style=\"display:none\">".($flexFirewall ? $goSSLAction : $installAction)."</ul>" : "")
			];
		}
		if($json->cipher->tls13!==null){
			if($showAll || !$json->cipher->tls13){
			$data[] = [
				"type" => "system-tls",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon((!$json->cipher->tls13 ? "ERROR" : "OK")) . "&nbsp;" . str_replace("%3%","<b>".pm_Locale::lmsg('Alert.SystemTLS')." TLS 1.3</b>",str_replace("%2%",pm_Locale::lmsg('Alert.TypeSystem'),str_replace("%1%","ssl.png",$imgTemplate))),
				"client" => pm_Locale::lmsg('Alert.TypeSystem'),
				"domain" => "",
				"info" => (!$json->cipher->tls13 ? "<span class=\"info-alert-msg-item\"><span class=\"pul-label pul-label--warning pul-label--caps\"><span class=\"pul-label__content\">" .pm_Locale::lmsg('Alert.SSLOK'). "</span></span></span>"  : pm_Locale::lmsg('Alert.EnableTLS')),
				"status" => (!$json->cipher->tls13 ? "ERROR" : "OK"),
				"action" =>  (!$json->cipher->tls13 ? "<ul class=\"pul-button-group\"  data-class=\"pul-button--ghost pul-button--empty\" data-svg=\"dots3\" style=\"display:none\">".($flexFirewall ? $goSSLAction : $installAction)."</ul>" : "")
			];
			}
		}

		if($showAll || $json->guest_user->status){
			$data[] = [
				"type" => "system-guest",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon(($json->guest_user->status ? "BAD" : "OK")) . "&nbsp;" . str_replace("%3%","<b>".pm_Locale::lmsg('Alert.GuestAccount')."</b>",str_replace("%2%",pm_Locale::lmsg('Alert.TypeUser'),str_replace("%1%","login.png",$imgTemplate))),
				"client" => pm_Locale::lmsg('Alert.TypeSystem'),
				"domain" => "",
				"info" => "<div class=\"info-alert\">" .$json->guest_user->name. "</div><div class=\"info-alert-msg\">". ($json->guest_user->status ? pm_Locale::lmsg('Alert.EnableAccount') : pm_Locale::lmsg('Alert.DisableAccount')) ."</div>" ,
				"status" => ($json->guest_user->status ? "BAD" : "OK"),
				"action" => ""
			];
		}
	
		$icount = 0;
		foreach ((array)$json->remote_users as $key => $value) {

			if(!$showAll){
				if(($value ? ($icount==0 ? true : false) : true)){continue;}
			}
			$data[] = [
				"type" => "remote_users",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon(($value ? ($icount==0 ? "OK" : "ERROR") : "OK")) . "&nbsp;" . str_replace("%3%","<b>".pm_Locale::lmsg('Alert.RemoteAccount')."</b>",str_replace("%2%",pm_Locale::lmsg('Alert.TypeUser'),str_replace("%1%","login.png",$imgTemplate))),
				"client" => pm_Locale::lmsg('Alert.TypeSystem'),
				"domain" => "",
				"info" => "<div class=\"info-alert\">" .$key. "</div><div class=\"info-alert-msg\">". ($value ? ( $icount>0 ? "<span class=\"pul-label pul-label--warning pul-label--caps\"><span class=\"pul-label__content\">" : "") . pm_Locale::lmsg('Alert.EnableAccount') . ( $icount>0 ? "</span></span></span>" : "")  : pm_Locale::lmsg('Alert.DisableAccount'))."</div>",
				"status" => ($value ? ($icount==0 ? "OK" : "ERROR") : "OK"),
				"action" =>  ($value ? ($icount==0 ? "" : "<ul class=\"pul-button-group\"  data-class=\"pul-button--ghost pul-button--empty\" data-svg=\"dots3\" style=\"display:none\">".($flexFirewall ? $goRemoteAction : $installAction)."</ul>") : "")
			];
			$icount++;
		}

		$icount = 0;
		foreach ((array)$json->admin_users as $key => $value) {

			if(!$showAll){
				if($value){continue;}
			}

			$data[] = [
				"type" => "admin_users",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon(($value ? ($icount<1 ? "OK" : "ERROR") : "OK")) . "&nbsp;" . str_replace("%3%","<b>".($icount<1 ? pm_Locale::lmsg('Alert.AdminAccount') : pm_Locale::lmsg('Alert.AdminAccountMulti'))."</b>",str_replace("%2%",pm_Locale::lmsg('Alert.TypeUser'),str_replace("%1%","admin.png",$imgTemplate))),
				"client" => pm_Locale::lmsg('Alert.TypeSystem'),
				"domain" => "",
				"info" => $value ? "<div class=\"info-alert-msg\">" . Modules_FlexClamServer_Helper::AlertInfo(($icount<1 ? "OK" : "ERROR")) . "</div>" : "",
				"info" => "<div class=\"info-alert\">" .$key. "</div><div class=\"info-alert-msg\">". ($value ? ($icount<1 ? pm_Locale::lmsg('Alert.EnableAccount') : "<span class=\"pul-label pul-label--warning pul-label--caps\"><span class=\"pul-label__content\">" . pm_Locale::lmsg('Alert.MultiAdminAccount') . "</span></span></span>") : pm_Locale::lmsg('Alert.DisableAccount'))."</div>",
				"status" => ($value ? ($icount<1 ? "OK" : "ERROR") : "OK"),
				"action" => ""
			];

			$icount++;

		}

		foreach ((array)$json->sys_users as $info) {

			if(!$showAll){
				if($info->status == "OK" || strlen($info->status)==1){continue;}
			}

			$date = gmdate("Y-m-d H:i:s", $info->date);
			$oneYearOn = date("Y-m-d H:i:s",strtotime(date("Y-m-d H:i:s") . " - 365 day"));
			$status = $info->status;
			if($status=="OK" && $oneYearOn>$date){$status = "ERROR";}

			$client = pm_Client::getByClientId($info->cid);

			$urlEdit = "/admin/subscription/login/id/".$info->wid."?pageUrl=/smb/ftp/users-list";
			$editAction="<li data-svg=\"edit\"><a href=\"".$urlEdit."\">".pm_Locale::lmsg('Action.Change')."</a></li>";

			$mailNoti = str_replace("%1","javascript:PleskExt.FlexClamServer.notiAction({'type':'TypeSYS','cid':".$info->cid.",'email' :'".$client->getProperty("email")."','client':'".$client->getProperty("pname")."','id':'".$info->login."','status':'".$info->status."'})",$notiAction);
			if($info->cid == 1 || $info->status=="OK"){$mailNoti ="";}

			$forceNoti = str_replace("%1","javascript:PleskExt.FlexClamServer.forceAction({'type': '". ($info->did == $info->wid ? "TypeSYS" : "TypeUser")."' ,'cid':".$info->cid.",'client':'".$client->getProperty("pname")."','id':'".$info->login."','status':'".$info->status."'})",$forceAction);

			$iconForce = " <img src=\"" . pm_Context::getBaseUrl() . "images/recheck.png\" title=\"".pm_Locale::lmsg('noti.ForceNoti')."\">";
			if($info->cid == 1){$iconForce = "";$forceNoti="";}else{
			if(Modules_FlexClamServer_Helper::ForceExist($client, ($info->did == $info->wid ? "TypeSYS'" : "TypeUser"),$info->login)){$forceNoti="";}else{$iconForce = "";}
			}


			$data[] = [
				"type" => "sys_users",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon($status) . "&nbsp;" . str_replace("%3%",$info->login,str_replace("%2%",pm_Locale::lmsg('Alert.TypeSYS'),str_replace("%1%","session.png",$imgTemplate))). $iconForce,
				"client" => ($info->cid == 1 ? "<img src=\"" . pm_Context::getBaseUrl() . "images/admin.png\"> " : "") . "<a href='/admin/customer/overview/id/".$info->cid."' title='".$client->getLogin()."'>".$client->getProperty("pname")."</a>",
				"domain" => "<a href='/admin/subscription/login/id/".$info->wid."?pageUrl=/smb/web/overview/id/".$info->did."/type/domain'>".pm_Domain::getByDomainId($info->did)->getDisplayName()."</a>",
				"info" => "<div class=\"info-alert\"><b>Path</b> : ".$info->home."</div><div class=\"info-alert-msg\">" . ($status=="ERROR" ? pm_Locale::lmsg('Alert.MustChanged') . Modules_FlexClamServer_Settings::FormatDateOutput($date,pm_Locale::lmsg('formatDate')) : ($status=="OK" ? pm_Locale::lmsg('Alert.DateChanged', ["date" => Modules_FlexClamServer_Settings::FormatDateOutput($date,pm_Locale::lmsg('formatDate'))])  : Modules_FlexClamServer_Helper::AlertInfo($status))) ."</div>",
				"status" => $status,
				"action" => "<ul class=\"pul-button-group\"  data-class=\"pul-button--ghost pul-button--empty\" data-svg=\"dots3\" style=\"display:none\">".$editAction.$mailNoti.$forceNoti."</ul>"
			];

		}

		foreach ((array)$json->smb_users as $info) {

			if(!$showAll){
				if($info->status == "OK" || strlen($info->status)==1){continue;}
			}

			$client = pm_Client::getByClientId($info->cid);

			$urlEdit = "/admin/".$info->type."/login-info/id/". $info->cid;
			$editAction="<li data-svg=\"edit\"><a href=\"".$urlEdit."\">".pm_Locale::lmsg('Action.Change')."</a></li>";

			$mailNoti = str_replace("%1","javascript:PleskExt.FlexClamServer.notiAction({'type':'TypeUser','cid':".$info->cid.",'email' :'".$client->getProperty("email")."','client':'".$client->getProperty("pname")."','id':'".$info->login."','status':'".$info->status."'})",$notiAction);
			if($info->cid == 1 || $info->status=="OK" || $info->type=="reseller"){$mailNoti ="";}

			$forceNoti = str_replace("%1","javascript:PleskExt.FlexClamServer.forceAction({'type':'TypeUser','cid':".$info->cid.",'client':'".$client->getProperty("pname")."','id':'".$info->login."','status':'".$info->status."'})",$forceAction);

			$iconForce = " <img src=\"" . pm_Context::getBaseUrl() . "images/recheck.png\" title=\"".pm_Locale::lmsg('noti.ForceNoti')."\">";
			if($info->cid == 1){$iconForce = "";$forceNoti="";}else{
			if(Modules_FlexClamServer_Helper::ForceExist($client,'TypeUser',$info->login)){$forceNoti="";}else{$iconForce = "";}
			}
			$data[] = [
				"type" => "smb_users",
				"alertType" =>  Modules_FlexClamServer_Helper::AlertStatusIcon($info->status) . "&nbsp;" . str_replace("%3%",$info->login,str_replace("%2%",pm_Locale::lmsg('Alert.TypeUser'),str_replace("%1%","login.png",$imgTemplate))) . $iconForce,
				"client" => ($info->cid == 1 ? "<img src=\"" . pm_Context::getBaseUrl() . "images/admin.png\"> " : "") . "<a href='/admin/customer/overview/id/".$info->cid."' title='".$info->login."'>".$info->name."</a>",
				"domain" => "",
				"info" => $info->status=="OK" ? "" : "<div class=\"info-alert-msg\">" . Modules_FlexClamServer_Helper::AlertInfo($info->status) . "</div>",
				"status" => $info->status,
				"action" => "<ul class=\"pul-button-group\"  data-class=\"pul-button--ghost pul-button--empty\" data-svg=\"dots3\" style=\"display:none\">".$editAction.$mailNoti.$forceNoti."</ul>"
			];

		}

		foreach ((array)$json->mail_users as $info) {

			if(!$showAll){
				if($info->status == "OK" || strlen($info->status)==1 ){continue;}
			}

			$client = pm_Client::getByClientId($info->cid);

			$urlEdit = "/admin/subscription/login/id/".$info->wid."?pageUrl=/smb/email-address/edit/id/".$info->eid;
			$editAction="<li data-svg=\"edit\"><a href=\"".$urlEdit."\">".pm_Locale::lmsg('Action.Change')."</a></li>";
			$mailNoti = str_replace("%1","javascript:PleskExt.FlexClamServer.notiAction({'type':'TypeMail','cid':".$info->cid.",'email' :'".$client->getProperty("email")."','client':'".$client->getProperty("pname")."','id':'".$info->email."','status':'".$info->status."'})",$notiAction);
			if($info->cid == 1 || $info->status=="OK"){$mailNoti ="";}

			$forceNoti = str_replace("%1","javascript:PleskExt.FlexClamServer.forceAction({'type':'TypeMail','cid':".$info->cid.",'client':'".$client->getProperty("pname")."','id':'".$info->email."','obj':".$info->eid.",'status':'".$info->status."'})",$forceAction);

			$iconForce = " <img src=\"" . pm_Context::getBaseUrl() . "images/recheck.png\" title=\"".pm_Locale::lmsg('noti.ForceNoti')."\">";
			if($info->cid == 1){$iconForce = "";$forceNoti="";}else{
			if(Modules_FlexClamServer_Helper::ForceExist($client,'TypeMail',$info->email.":".$info->eid)){$forceNoti="";}else{$iconForce = "";}
			}

			$data[] = [
				"type" => "mail_users",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon($info->status) . "&nbsp;" . str_replace("%3%",$info->email,str_replace("%2%",pm_Locale::lmsg('Alert.TypeMail'),str_replace("%1%","mail.png",$imgTemplate))) . $iconForce,
				"client" => ($info->cid == 1 ? "<img src=\"" . pm_Context::getBaseUrl() . "images/admin.png\"> " : "") . "<a href='/admin/customer/overview/id/".$info->cid."' title='".$client->getLogin()."'>".$client->getProperty("pname")."</a>",
				"domain" => "<a href='/admin/subscription/login/id/".$info->wid."?pageUrl=/smb/web/overview/id/".$info->did."/type/domain'>".pm_Domain::getByDomainId($info->did)->getDisplayName()."</a>",
				"info" => $info->status=="OK" ? "" : "<div class=\"info-alert-msg\">" . Modules_FlexClamServer_Helper::AlertInfo($info->status) . "</div>",
				"status" => $info->status,
				"action" => "<ul class=\"pul-button-group\"  data-class=\"pul-button--ghost pul-button--empty\" data-svg=\"dots3\" style=\"display:none\">".$editAction.$mailNoti.$forceNoti."</ul>"
			];




		}

		foreach ((array)$json->client_users as $info) {

			if(!$showAll){
				if($info->status == "OK" || strlen($info->status)==1){continue;}
			}

			$client = pm_Client::getByClientId($info->cid);

			$urlEdit = "/admin/customer/login-info/id/".$info->cid;
			$editAction="<li data-svg=\"edit\"><a href=\"".$urlEdit."\">".pm_Locale::lmsg('Action.Change')."</a></li>";


			$iconForce = " <img src=\"" . pm_Context::getBaseUrl() . "images/recheck.png\" title=\"".pm_Locale::lmsg('noti.ForceNoti')."\">";

			$forceNoti = str_replace("%1","javascript:PleskExt.FlexClamServer.forceAction({'type': 'TypeUser' ,'cid':".$info->cid.",'client':'".$client->getProperty("pname")."','id':'".$info->login."','status':'".$info->status."'})",$forceAction);

			if($info->cid == 1){$iconForce = "";$forceNoti="";}else{
			if( Modules_FlexClamServer_Helper::ForceExist($client,'TypeUser',$info->login)){$forceNoti="";}else{$iconForce = "";}
			}
			$data[] = [
				"type" => "client_users",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon($info->status) . "&nbsp;" . str_replace("%3%",pm_Locale::lmsg('Alert.UserAccount'),str_replace("%2%",pm_Locale::lmsg('Alert.TypeUser'),str_replace("%1%","login.png",$imgTemplate))),
				"client" => ($info->cid == 1 ? "<img src=\"" . pm_Context::getBaseUrl() . "images/admin.png\"> " : "") . "<a href='/admin/customer/overview/id/".$info->cid."' title='".$info->login."'>".$info->name."</a>",
				"domain" => "",
				"info" => $info->status=="OK" ? "" : "<div class=\"info-alert-msg\">" . Modules_FlexClamServer_Helper::AlertInfo($info->status) . "</div>",
				"status" => $info->status,
				"action" => "<ul class=\"pul-button-group\"  data-class=\"pul-button--ghost pul-button--empty\" data-svg=\"dots3\" style=\"display:none\">".$editAction.$forceNoti."</ul>"
			];

		}

		foreach ((array)$json->db_users as $info) {

			if(!$showAll){
				if($info->status == "OK" || strlen($info->status)==1){continue;}
			}

			$client = pm_Client::getByClientId($info->cid);

			$urlEdit = "/admin/subscription/login/id/".$info->wid."?pageUrl=/smb/database/users-list/domainId/".$info->did;
			$editAction="<li data-svg=\"edit\"><a href=\"".$urlEdit."\">".pm_Locale::lmsg('Action.Change')."</a></li>";

			$mailNoti = str_replace("%1","javascript:PleskExt.FlexClamServer.notiAction({'type':'TypeDB','cid':".$info->cid.",'email' :'".$client->getProperty("email")."','client':'".$client->getProperty("pname")."','id':'".$info->name."','status':'".$info->status."'})",$notiAction);
			if($info->cid == 1 || $info->status=="OK"){$mailNoti ="";}

			$forceNoti = str_replace("%1","javascript:PleskExt.FlexClamServer.forceAction({'type':'TypeDB','cid':".$info->cid.",'client':'".$client->getProperty("pname")."','obj':".$info->did.",'id':'".$info->name."','status':'".$info->status."'})",$forceAction);

			$iconForce = " <img src=\"" . pm_Context::getBaseUrl() . "images/recheck.png\" title=\"".pm_Locale::lmsg('noti.ForceNoti')."\">";
			if($info->cid == 1){$iconForce = "";$forceNoti="";}else{
			if( Modules_FlexClamServer_Helper::ForceExist($client,'TypeDB',$info->name.":".$info->did)){$forceNoti="";}else{$iconForce = "";}
			}
			$data[] = [
				"type" => "db_users",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon($info->status) . "&nbsp;" . str_replace("%3%",$info->name,str_replace("%2%",pm_Locale::lmsg('Alert.TypeDB'),str_replace("%1%","databases.png",$imgTemplate))). $iconForce,
				"client" => ($info->cid == 1 ? "<img src=\"" . pm_Context::getBaseUrl() . "images/admin.png\"> " : "") . "<a href='/admin/customer/overview/id/".$info->cid."' title='".$client->getLogin()."'>".$client->getProperty("pname")."</a>",
				"domain" => "<a href='/admin/subscription/login/id/".$info->wid."?pageUrl=/smb/web/overview/id/".$info->did."/type/domain'>".pm_Domain::getByDomainId($info->did)->getDisplayName()."</a>",
				"info" => $info->status=="OK" ? "" : "<div class=\"info-alert\"><b>Server</b> : ".$info->server."</div><div class=\"info-alert-msg\">" . Modules_FlexClamServer_Helper::AlertInfo($info->status)."</div>",
				"status" => $info->status,
				"action" => "<ul class=\"pul-button-group\"  data-class=\"pul-button--ghost pul-button--empty\" data-svg=\"dots3\" style=\"display:none\">".$editAction.$mailNoti.$forceNoti."</ul>"
			];

		}


		foreach ((array)$json->dir_users as $info) {

			if(!$showAll){
				if($info->status == "OK"){continue;}
			}

			$client = pm_Client::getByClientId($info->cid);

			$urlEdit = "/admin/subscription/login/id/".$info->wid."?pageUrl=/cp/domains/".$info->did."/protected-directories";
			$editAction="<li data-svg=\"edit\"><a href=\"".$urlEdit."\">".pm_Locale::lmsg('Action.Change')."</a></li>";

			$mailNoti = str_replace("%1","javascript:PleskExt.FlexClamServer.notiAction({'type':'TypeDir','cid':".$info->cid.",'email' :'".$client->getProperty("email")."','client':'".$client->getProperty("pname")."','id':'\\\\".$info->dir."','status':'".$info->status."'})",$notiAction);
			if($info->cid == 1 || $info->status=="OK" || $info->dir=="plesk-stat"){$mailNoti ="";}

			$data[] = [
				"type" => "dir_users",
				"alertType" => Modules_FlexClamServer_Helper::AlertStatusIcon($info->status) . "&nbsp;" . str_replace("%3%",pm_Locale::lmsg('Alert.DirAccount'),str_replace("%2%",pm_Locale::lmsg('Alert.TypeDir'),str_replace("%1%","dir-server.png",$imgTemplate))),
				"client" => ($info->cid == 1 ? "<img src=\"" . pm_Context::getBaseUrl() . "images/admin.png\"> " : "") . "<a href='/admin/customer/overview/id/".$info->cid."' title='".$client->getLogin()."'>".$client->getProperty("pname")."</a>",
				"domain" => "<a href='/admin/subscription/login/id/".$info->wid."?pageUrl=/smb/web/overview/id/".$info->did."/type/domain'>".pm_Domain::getByDomainId($info->did)->getDisplayName()."</a>",
				"info" => $info->status=="OK" ? "" : "<div class=\"info-alert\">".$info->name."<br><b>Path</b> : \\".$info->dir."</div><div class=\"info-alert-msg\">" .Modules_FlexClamServer_Helper::AlertInfo($info->status) . "</div>",
				"status" => $info->status,
				"action" => "<ul class=\"pul-button-group\"  data-class=\"pul-button--ghost pul-button--empty\" data-class\"pul-button--ghost pul-button--empty\" data-svg=\"dots3\" style=\"display:none\">".$editAction.$mailNoti."</ul>"
			];

		}


	}



    	$options = [
            'defaultSortField' => 'type',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_DOWN,
        ];
        $list = new pm_View_List_Simple($this->view, $this->_request, $options);
        $list->setData($data);
        $list->setColumns([
            'alertType' => [
                'title' => $this->lmsg('Alert.Type'),
                'noEscape' => true,
                'searchable' => false,
                'sortable' => true,
            ],
            'client' => [
                'title' => $this->lmsg('Alert.Client'),
                'noEscape' => true,
                'searchable' => true,
                'sortable' => true,
            ],
            'domain' => [
                'title' => $this->lmsg('Alert.Domain'),
                'noEscape' => true,
                'searchable' => true,
                'sortable' => true,
            ],
            'info' => [
                'title' => $this->lmsg('Alert.Info'),
                'noEscape' => true,
                'searchable' => true,
                'sortable' => false,
            ],
            'action' => [
                'title' => $this->lmsg('Alert.Actions'),
                'noEscape' => true,
                'searchable' => false,
                'sortable' => false,
            ],
        ]);

        $list->setDataUrl(['action' => 'alert-data']);

        return [$scandate,$list];


    }

    public function alertDataAction(){  
	$showAll = $this->_getParam('view') == '1' ? true : false;
        $list = $this->_getAlertList($showAll)[1];
        $this->_helper->json($list->fetchData());
    }



     public function notiAction(){

	$client = pm_Client::getByClientId($this->_getParam("cid"));
	$subject = pm_Locale::lmsg('Alert.Info') . " : " . $this->_getParam("id");
	$body = pm_Locale::lmsg(
        	        'Message.MailNoti',[
	                    'client' => $this->_getParam("client"),
	                    'type' =>  pm_Locale::lmsg("Alert.".$this->_getParam("type")),
        	            'id' => $this->_getParam("id")
                	]
	            );

	$notificationManager = new pm_Notification();
	$notificationManager->send("email_customer", ['subject-text' => $subject,'message-text' => $body],$client);

	if( $this->_getParam("type") == "TypeMail" && $this->_getParam("email") !== $client->getProperty('id') ){

		try {
			$admin = pm_Client::getAdmin();
		        $mail = new Zend_Mail("UTF-8");
        		$mail->setBodyText($body);
	        	$mail->setFrom($admin->getProperty('email'), $admin->getProperty('cname'));
	        	$mail->addTo($this->_getParam("id"), $this->_getParam("client"));
		        $mail->setSubject("[".pm_Locale::lmsg("Alert.TypeSystem")."] " . $subject);
        		$mail->send();
	        } catch (pm_Exception $e) {
		}
	}

	$this->_helper->json(['noti' => pm_Locale::lmsg("noti.MailNoti",["email" => $client->getProperty('email')])]);

      }

     public function forceAction(){

	$client = pm_Client::getByClientId($this->_getParam("cid"));

	if($this->_getParam("type")=="TypeUser"){
		$client->setSetting("ForceTypeUser","1");
	}

	if($this->_getParam("type")=="TypeSYS"){
		$data = $client->getSetting("ForceTypeSYS",null);
		$list = [];
		if($data!=null){$list = explode(",",$data);}

		if(!isset($list[$this->_getParam("id")])){
			$list[] = $this->_getParam("id");
			$client->setSetting("ForceTypeSYS",implode(",",$list));
		}
	}

	if($this->_getParam("type")=="TypeDB"){
		$data = $client->getSetting("ForceTypeDB",null);
		$list = [];
		if($data!=null){$list = explode(",",$data);}

		if(!isset($list[$this->_getParam("id")])){
			$list[] = $this->_getParam("id");
			$client->setSetting("ForceTypeDB",implode(",",$list));
		}
		
	}	

	if($this->_getParam("type")=="TypeMail"){
		$data = $client->getSetting("ForceTypeMail",null);
		$list = [];
		if($data!=null){$list = explode(",",$data);}

		if(!isset($list[$this->_getParam("id").":".$this->_getParam("obj")])){
			$list[] = $this->_getParam("id").":".$this->_getParam("obj");
			$client->setSetting("ForceTypeMail",implode(",",$list));
		}
		
	}	

	$this->_helper->json(['noti' => pm_Locale::lmsg("noti.ForceNoti")]);

      }
 
}
