<?php
/**
 * Copyright 2025 Flex Clam Server for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2025 Flex Clam Server for Plesk
 * @author Flex Antivirus <info@antivirus.flexservices.app>
 * @license Copyright
 */


class Modules_FlexClamServer_ContentInclude extends pm_Hook_ContentInclude{


	public function init(){


	        $excludeUrls = [
	            '/server/key_info.php',
        	    '/server/key_upload.php',
	            '/server/key_update.php',
        	    '/server/key_revert.php',
	            '/plesk/license/',
	            '/smb/settings/tools-proxy',
        	    '/smb/help/',
	            '/cp/license/primary',
	            '/cp/license/additional/',
	            '/modules/flex-clam-server/',
	            '/modules/flex-firewall-manager/',
	            '/modules/flex-firewall-manager/index.php/index/index',
	            '/modules/repair-kit/index.php',
	            '/smb/my-profile/',
	            '/smb/database/users-list/domainId/',
	            '/smb/database/edit-user/id/',
	            '/smb/email-address/edit/',
	            '/admin/reseller/login-info/',
	            '/admin/reseller/logout',
	            '/admin/customer/logout',
	            'logout.php',
	            '/smb/ftp/users-list',
	            '/smb/web/view/1/hosting-settings',
	            '/smb/task/task-progress',
	            '/admin/task/task-progress',
	            '/admin/notifications/update',
	            '/admin/notifications/list',
	            '/cp/server/about',
	            '/admin/index/eula',
	            '/cp/locale',
	            '/cp/graphql',
	            '/smb/web/domain-look-up',
        	];


	        foreach ($excludeUrls as $excludeUrl) {
        	    if (str_contains($_SERVER['REQUEST_URI'], $excludeUrl)) {
	                return true;
        	    }
	        }


		$client = pm_Session::getClient();

		$redirectUrl = '';
		$msg = '';

		if($client->getSetting("ForceTypeUser","0")=="1"){
			if($client->isReseller()){
				$redirectUrl="/admin/reseller/login-info/?context=credentials-info";
			}else{
				$redirectUrl="/smb/my-profile/";
			}
			$msg = "<b>".$client->getLogin()."</b>";
		}
		if($redirectUrl==''){
			$data = $client->getSetting("ForceTypeSYS",null);
			if($data!==null){
				$list = explode(",",$data);
				$redirectUrl = "/smb/ftp/users-list";
				$msg = "<b>".$list[0]."</b>";
			}
		}

		if($redirectUrl==''){
			$data = $client->getSetting("ForceTypeDB",null);
			if($data!==null){
				$list = explode(",",$data);
				$cuenta = explode(":",$list[0]);
				$redirectUrl = "/smb/database/users-list/domainId/".$cuenta[1];
				$msg = "<b>".$cuenta[0]."</b>";

			}
		}

		if($redirectUrl==''){
			$data = $client->getSetting("ForceTypeMail",null);
			if($data!==null){
				$list = explode(",",$data);
				$cuenta = explode(":",$list[0]);
				$redirectUrl="/smb/email-address/edit/id/".$cuenta[1];
				$msg = "<b>".$cuenta[0]."</b>";
			}
		}


		if($redirectUrl!=''){

			pm_View_Status::addWarning(pm_Locale::lmsg("Message.ForceNoti",["id" => $msg]),true);
	  		Zend_Controller_Action_HelperBroker::getStaticHelper('redirector')->gotoUrl(($_SERVER['HTTPS'] == 'on' ? "https://" : "http://") . $_SERVER['HTTP_HOST'] . $redirectUrl);
		        exit;
		}


	}

	public function getJsConfig(){
		return [
		"BaseUrl" => pm_Context::getBaseUrl(),
		"Lang" => [
			"Yes" => pm_Locale::lmsg("Action.Yes"),
			"No" => pm_Locale::lmsg("Action.No"),
			"Cancel" => pm_Locale::lmsg("Action.Cancel"),
			"NotiMailPass" => pm_Locale::lmsg("Message.NotiMailPass"),
			"NotiForcePass" => pm_Locale::lmsg("Message.NotiForcePass"),
			"TypeUser" => pm_Locale::lmsg("Alert.TypeUser"),
			"TypeSYS" => pm_Locale::lmsg("Alert.TypeSYS"),
			"TypeMail" => pm_Locale::lmsg("Alert.TypeMail"),
			"TypeDB" => pm_Locale::lmsg("Alert.TypeDB"),
			"TypeDir" => pm_Locale::lmsg("Alert.TypeDir"),
			"HomePage" =>  pm_Locale::lmsg('pageHome'),
			"HomeTextLink" =>  pm_Locale::lmsg('tabVirus'),
			"HomeUrlLink" =>  pm_Context::getActionUrl('index','virus'),

		]
		];
	}

}