<?php
/**
 * Copyright 2025 Flex Clam Server for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2025 Flex Clam Server for Plesk
 * @author Flex Antivirus <info@antivirus.flexservices.app>
 * @license Copyright
 */

class Modules_FlexClamServer_EventListener implements EventListener
{
    public function filterActions()
    {
        return ["mailname_update","reseller_update","client_update","database_user_update"];
    }


    public function handleEvent($objectType, $objectId, $action, $oldValues, $newValues){


	error_log("[FlexClamServer] Type: " . $objectType);
	error_log("[FlexClamServer] Action: " . $action);
	error_log("[FlexClamServer] ID: " . var_export($objectId, true));
	error_log("[FlexClamServer] Old Values: " . var_export($oldValues, true));
	error_log("[FlexClamServer] New Values: " . var_export($newValues, true));


        switch ($action) {
            case "mailname_update":
			// mail_users
			$email = $newValues["Mailname"];
			$did = $newValues["Domain Id"];
			$domain = pm_Domain::getByDomainId($did);
			$client = $domain->getClient();
			$cid = $client->getId();
			$hash = hash('sha256', $newValues["Password"]);

			Modules_FlexClamServer_Helper::ForceRemove($client,"TypeMail",$email.":".$objectId);

                break;
            case "reseller_update":
			// smb_users
			$login = $newValues["Login Name"];
			$cid = $objectId;
			$hash = hash('sha256', $newValues["Password"]);
			$client = pm_Client::getByLogin($login);

			Modules_FlexClamServer_Helper::ForceRemove($client,"TypeUser",$objectId);

                break;
            case "client_update":
			// smb_users
			$login = $newValues["Login Name"];
			$cid = $objectId;
			$hash = hash('sha256', $newValues["Password"]);
			$client = pm_Client::getByLogin($login);

			Modules_FlexClamServer_Helper::ForceRemove($client,"TypeUser",$objectId);

                break;
	    case "database_user_update":
			// db_users
			$login = $newValues["Database user name"];
			$did = $newValues["Domain Id"];
			$domain = pm_Domain::getByDomainId($did);
			$client = $domain->getClient();
			$cid = $client->getId();
			$hash = hash('sha256', $newValues["Database user password"]);

			Modules_FlexClamServer_Helper::ForceRemove($client,"TypeDB",$login.":".$did);

                break;
        }
    }
}

return new Modules_FlexClamServer_EventListener();
