<?php
/**
 * Copyright 2025 Flex Clam Server for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2025 Flex Clam Server for Plesk
 * @author Flex Antivirus <info@antivirus.flexservices.app>
 * @license Copyright
 */

class Modules_FlexClamServer_Form_Settings extends pm_Form_Simple{

    const FCS_AutoScan = 'EnableAutoScan';
    const FCS_ScanOnStartUp = 'ScanOnStartUp';
    const FCS_AutoActionSYS = 'AutoScanActionSYS';
    const FCS_AutoActionDOM = 'AutoScanActionDOM';
    const FCS_NotiEmail = 'EnableNotiEmail';
    const FCS_AutoRAM = 'AutoRAM';

    private $isConsole = false;
    private $isLicensed = false;
    

    public function __construct($options = []){
        if (!empty($options['isConsole'])) {
            $this->isConsole = $options['isConsole'];
        }

        if (!empty($options['isLicensed'])) {
            $this->isLicensed = $options['isLicensed'];
        }

        parent::__construct($options);
    }


    public function init(){
        parent::init();

		$Actions = array('nothing' => pm_Locale::lmsg('Action.None'), 'delete' => pm_Locale::lmsg('Action.Delete'));
		$AutoTypeTime = array('morning' => pm_Locale::lmsg('Settings.DailyMorning'), 'night' => pm_Locale::lmsg('Settings.DailyNight'), 'disabled' => pm_Locale::lmsg('Settings.DailyNone'));

		if($this->isLicensed){
			$AutoTypeTime = array('hour' => pm_Locale::lmsg('Settings.DailyHour'), 'morning' => pm_Locale::lmsg('Settings.DailyMorning'), 'night' => pm_Locale::lmsg('Settings.DailyNight'), 'disabled' => pm_Locale::lmsg('Settings.DailyNone'));
		}


	        $this->addElement('hidden', static::FCS_AutoScan, [
        	    'title'      => pm_Locale::lmsg('Settings.AutoScan'),
        	    'data-description'      => pm_Locale::lmsg('Settings.AutoScanDesc'),
        	    'data-tooltip'      => pm_Locale::lmsg('Settings.AutoScanDesc'),
	            'value'      => Modules_FlexClamServer_Settings::Get(static::FCS_AutoScan,1),
        	    'required'   => false,
        	    'class'   => 'switch',
	            'validators' => [],
	        ]);

	        $this->addElement('hidden', static::FCS_ScanOnStartUp, [
        	    'title'      => pm_Locale::lmsg('Settings.ScanOnStartUp'),
        	    'data-description'      => pm_Locale::lmsg('Settings.ScanOnStartUpDesc'),
        	    'data-tooltip'      => pm_Locale::lmsg('Settings.ScanOnStartUpDesc'),
	            'value'      => Modules_FlexClamServer_Settings::Get(static::FCS_ScanOnStartUp,0),
        	    'required'   => false,
        	    'class'   => 'switch',
	            'validators' => [],
	        ]);

		$this->addElement('select', "AutoTypeScan", [
        	    'label'      => pm_Locale::lmsg('Settings.AutoTypeScan'),
         	    'data-tooltip' => pm_Locale::lmsg('Settings.AutoTypeScanDesc'),
        	    'multiOptions' => $AutoTypeTime,
        	    'value' => pm_Settings::get("AutoTypeScan", "night"),
        	    'required' => true,
		]);

		$this->addElement('select', "AutoRAM", [
        	    'label'      => pm_Locale::lmsg('Settings.AutoTypeRam'),
        	    'multiOptions' => $AutoTypeTime,
        	    'value' => pm_Settings::get("AutoTypeRam", "night"),
        	    'required' => true,
		]);



	        $this->addElement('hidden', static::FCS_NotiEmail, [
        	    'title'      => pm_Locale::lmsg('Settings.NotiMail'),
	            'value'      => Modules_FlexClamServer_Settings::Get(static::FCS_NotiEmail,0),
        	    'required'   => false,
        	    'class'   => 'switch',
	            'validators' => [],
	        ]);

		$this->addElement('select', static::FCS_AutoActionSYS, [
        	    'label'      => pm_Locale::lmsg('Settings.ActionSYS'),
         	    'data-tooltip' => pm_Locale::lmsg('Settings.ActionSYSDesc'),
        	    'multiOptions' => $Actions,
        	    'value' => Modules_FlexClamServer_Settings::Get(static::FCS_AutoActionSYS,"nothing"),
        	    'required' => true,
		]);

		$this->addElement('select', static::FCS_AutoActionDOM, [
        	    'label'      => pm_Locale::lmsg('Settings.ActionDOM'),
         	    'data-tooltip' => pm_Locale::lmsg('Settings.ActionDOMDesc'),
        	    'multiOptions' => $Actions,
        	    'value' => Modules_FlexClamServer_Settings::Get(static::FCS_AutoActionDOM,"nothing"),
        	    'required' => true,
		]);

        $this->addControlButtons([
            'cancelHidden' => true,
        ]);


    }


    public function isValid($data){
        if (!parent::isValid($data)) {
            $this->markAsError();
            return false;
        }

        return true;
    }


    public function process(){


	Modules_FlexClamServer_Settings::Save(static::FCS_AutoScan, $this->getValue(static::FCS_AutoScan));
	Modules_FlexClamServer_Settings::Save(static::FCS_ScanOnStartUp, $this->getValue(static::FCS_ScanOnStartUp));
	Modules_FlexClamServer_Settings::Save(static::FCS_NotiEmail, $this->getValue(static::FCS_NotiEmail));
	Modules_FlexClamServer_Settings::Save(static::FCS_AutoActionSYS, $this->getValue(static::FCS_AutoActionSYS));
	Modules_FlexClamServer_Settings::Save(static::FCS_AutoActionDOM, $this->getValue(static::FCS_AutoActionDOM));
	Modules_FlexClamServer_Settings::Save(static::FCS_AutoRAM, $this->getValue(static::FCS_AutoRAM));


	pm_Settings::set("AutoTypeScan", $this->getValue("AutoTypeScan"));
	pm_Settings::set("AutoTypeRam", $this->getValue("AutoTypeRam"));

	Modules_FlexClamServer_Settings::AutoTypeScan();
	Modules_FlexClamServer_Settings::AutoTypeRam();

	return true;
     } 



 }



