<?php
/**
 * Copyright 2025 Flex Clam Server for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2025 Flex Clam Server for Plesk
 * @author Flex Antivirus <info@antivirus.flexservices.app>
 * @license Copyright
 */

class Modules_FlexClamServer_Helper{


    /**
     * Get Lang Code
     * @return String		2 Chars
     */
    public static function LangCode(){
	return substr(pm_Locale::getCode(), 0, 2);
    }

    /**
     * Get Client Types
     * @return Boolean		True or Flase
     */
    public static function AdminAuth(){
	return pm_Session::getClient()->isAdmin();
    }
    public static function ResellerAuth(){
	return pm_Session::getClient()->isReseller();
    }
    public static function ClientAuth(){
	return pm_Session::getClient()->isClient();
    }

    /**
     * Get Ext Temp Directory
     * @return String		String Path
     */
    public static function TempPathLog(){
	return pm_Context::getVarDir() . "logs\\";
    }

    /**
     * Count round thousand to a K style count like facebook
     *
     * @param $size		Numeric
     * @param $round		Numeric (0,1,2,3,4)
     *
     * @return String		Style Conversion String
     */
    public static function StyleCount($size,$round = 2){
	if($size==0){return $size;}
	$unit=['', 'K', 'M', 'G', 'T','P'];
    	return round($size/pow(1000,($i=floor(log($size,1000)))),$round).$unit[$i];
    }

    public static function StyleSize($size,$round = 1){
	if($size==0){return "0 Kb";}

	$unit=['bytes', 'Kb', 'Mb', 'Gb', 'Tb','Pb'];
    	return round($size/pow(1024,($i=floor(log($size,1024)))),$round).$unit[$i];
    }

    /**
     * Get All Domains with hosting type
     *
     * @return Array		Data List
     */
	public static function GetAllDomains($session = true){

		$ListDomains=[];
		$ListPath=[];

		foreach(pm_Domain::getAllDomains(false) as $domain){
			if($session){
	            		if (!pm_Session::getClient()->isAdmin() && !pm_Session::getClient()->hasAccessToDomain($domain->getId())) {
        	        		continue;
            			}
			}

			if($domain->hasHosting()){

				if(in_array($domain->getHomePath(),$ListPath)){continue;}

				$ListPath[] = $domain->getHomePath();

			 	$ListDomains[$domain->getId()] = [
        	        		'id' => $domain->getId(),
                			'name' => $domain->getDisplayName(),
                			'client' => $domain->getClient()->getId(),
                			'suscription' => ($domain->getProperty("webspace_id")==0 ? $domain->getId() : $domain->getProperty("webspace_id")),
                			'hostSize' => $domain->getProperty("real_size"),
                			'hostPath' => str_replace("/", "\\", $domain->getHomePath()),
                			'status' => $domain->isActive() ? 'On' : 'Off',
					'enable' => filter_var($domain->getSetting("enable",true), FILTER_VALIDATE_BOOLEAN),
					'scanning' => filter_var($domain->getSetting("scanning",false), FILTER_VALIDATE_BOOLEAN),
					'idTask' => $domain->getSetting("idTask",0),
					'lastScan' => $domain->getSetting("lastScan",null),
					'warnings' => $domain->getSetting("warnings",0),
  		            	];
			}


		}


		return $ListDomains;

	}


    /**
     * Save Flag Domain
     *
     * @param $domainId		Numeric ID
     * @param $type		Boolean
     */
	public static function ScanStatusFlag($domainId,$type){
		pm_Domain::getByDomainId($domainId)->setSetting("lastScan",time());
		pm_Domain::getByDomainId($domainId)->setSetting("scanning",$type);
	}

    /**
     * Alert Status Icon
     *
     * @param $status	String
     */
	public static function AlertStatusIcon($status,$title=null){
		$imgTemplate = "";
		if($status=="OK"){
			$imgTemplate = "<img src=\"" . pm_Context::getBaseUrl() . "images/on.png\" title=\"".($title==null ? pm_Locale::lmsg('Alert.StatusOK') : $title)."\">";
		}else if($status=="BAD"){
			$imgTemplate = "<img src=\"" . pm_Context::getBaseUrl() . "images/bad.png\" title=\"".($title==null ? pm_Locale::lmsg('Alert.StatusBAD') : $title)."\">";
		}else if($status=="OLD"){
			$imgTemplate = "<img src=\"" . pm_Context::getBaseUrl() . "images/bad.png\" title=\"".($title==null ? pm_Locale::lmsg('Alert.StatusOLD') : $title)."\">";
		}else{
			$imgTemplate = "<img src=\"" . pm_Context::getBaseUrl() . "images/warning.png\" title=\"".pm_Locale::lmsg('Alert.StatusCHK')."\">";
		}

		return $imgTemplate;
	}


    /**
     * Alert Info using Status
     *
     * @param $status	String
     */
	public static function AlertInfo($status){
		$info = "";
		if($status=="OK"){

		}else if($status=="BAD"){
			$info = "<img src=\"" . pm_Context::getBaseUrl() . "images/bad.png\" title=\"".pm_Locale::lmsg('Alert.StatusBAD')."\"> <span class=\"pul-label pul-label--danger pul-label--caps\"><span class=\"pul-label__content\">" . pm_Locale::lmsg('Alert.StatusBAD'). "</span></span>";
		}else if($status=="OLD"){
			$info = "<img src=\"" . pm_Context::getBaseUrl() . "images/bad.png\" title=\"".pm_Locale::lmsg('Alert.StatusOLD')."\"> <span class=\"pul-label pul-label--danger pul-label--caps\"><span class=\"pul-label__content\">" . pm_Locale::lmsg('Alert.StatusOLD'). "</span></span>";
		}else{
		
		$color = "inactive";
		if(strlen($status)>1){$color = "warning";}

		foreach (str_split($status) as $char) {
			$info = $info . "<span class=\"info-alert-msg-item\"><span class=\"pul-label pul-label--".$color." pul-label--caps\"><span class=\"pul-label__content\">" . pm_Locale::lmsg('Alert.StatusCHK'.$char). "</span></span></span>";
		}
		

		}

		return $info;
	}

    /**
     * Read Stats File
     *
     * @param $statsInfo	Name of file to read without ext
     *
     * @return Array		Data with information
     */
	public static function StatsInfo($statsInfo){

		$stats = [];

		$fileManager = new pm_ServerFileManager();
		$filePath = pm_Context::getVarDir() . "\\Stats".$statsInfo.".cfg";
		if (!$fileManager->fileExists($filePath)) {
			return $stats;
		}else{
			$content = explode("\n",$fileManager->fileGetContents($filePath));

			foreach ($content as $line) {
				if(strlen($line)>1){
					$data = explode("\t",$line);
					$stats[$data[0]] = [
						strtolower($statsInfo) => $data[0],
						'total' => $data[1],
						'scan' => $data[2],
						'error' => $data[3],
						'normal' => $data[4],
						'found' => $data[5]
					];
				}
			}

			ksort($stats);

			return $stats;
		}
		
	}

    /**
     * Check if Extension Exist
     *
     * @param $id	Extension Id Name
     *
     * @return Boolean		Is Active
     */
	public static function ExtExist($id){
		try{
			return pm_Extension::getById($id)->isActive();
		}catch(exception $e){
			return false;
		}
	}



    /**
     * Check if Force Password Exist
     *
     * @param $client	pm_Client
     * @param $type	String
     * @param $id	String
     *
     * @return Boolean		Is Active
     */
	public static function ForceExist($client,$type,$id){
		$found = false;

		if($type=="TypeUser"){
			if($client->getSetting("ForceTypeUser","0")=="1"){
				$found = true;
			}
		}

		if($type=="TypeSYS"){
			$found = false;
			$data = $client->getSetting("ForceTypeSYS",null);
			if($data!==null){
				$list = explode(",",$data);
				foreach (explode(",",$data) as $item) {
					if($item==$id){
						$found = true;
						break;
					}
				}
			}
		}	

		if($type=="TypeDB"){
			$found = false;
			$data = $client->getSetting("ForceTypeDB",null);
			if($data!==null){
				$list = explode(",",$data);
				foreach (explode(",",$data) as $item) {
					if($item==$id){
						$found = true;
						break;
					}
				}
			}
		}

		if($type=="TypeMail"){
			$data = $client->getSetting("ForceTypeMail",null);
			if($data!==null){
				$list = explode(",",$data);
				foreach (explode(",",$data) as $item) {
					if($item==$id){
						$found = true;
						break;
					}
				}
			}
		}

		return $found;	

	}


    /**
     * Remove Force Flag
     *
     * @param $client	pm_Client
     * @param $type	String
     * @param $id	String
     *
     * @return Boolean		Is Active
     */
	public static function ForceRemove($client,$type,$id){

		if($type=="TypeUser"){
			if($client->getSetting("ForceTypeUser","0")=="1"){
				$client->setSetting("ForceTypeUser",null);
				return true;
			}
		}

		if($type=="TypeSYS"){
			$data = $client->getSetting("ForceTypeSYS",null);
			if($data===null){return true;}
			$list = explode(",",$data);
			unset($list[0]);
			if(count($list)==0){
				$client->setSetting("ForceTypeSYS",null);
			}else{
				$client->setSetting("ForceTypeSYS",implode(",",$list));
			}
			return true;
		}
	
		if($type=="TypeDB"){
			$data = $client->getSetting("ForceTypeDB",null);
			if($data===null){return true;}
			$list = explode(",",$data);
			unset($list[$id]);
			if(count($list)==0){
				$client->setSetting("ForceTypeDB",null);
			}else{
				$client->setSetting("ForceTypeDB",implode(",",$list));
			}
			return true;
		}

		if($type=="TypeMail"){
			$data = $client->getSetting("ForceTypeMail",null);
			if($data===null){return true;}
			$list = explode(",",$data);
			unset($list[0]);
			if(count($list)==0){
				$client->setSetting("ForceTypeMail",null);
			}else{
				$client->setSetting("ForceTypeMail",implode(",",$list));
			}
			return true;
		}

		return false;	
	}

}