<?php
/**
 * Copyright 2025 Flex Clam Server for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2025 Flex Clam Server for Plesk
 * @author Flex Antivirus <info@antivirus.flexservices.app>
 * @license Copyright
 */

class Modules_FlexClamServer_Mail{

    /**
     * Start Check Step to init
     *
     * @param $account		String Name of email account
     * @param $domain		String Domain Name of email account
     */
	public static function Start($account,$domain, $idTask){

		$path = $account . "@" . $domain;
		$log = Modules_FlexClamServer_Helper::TempPathLog() . $path . ".log";

		pm_Log::info("FlexClamServer : Scan " . $path);

		$Status = pm_ApiCli::callSbin("FlexClamServer.exe",array("-task-mail",$path,$log,"-json"),1);
		if($Status['code']>0){throw new pm_Exception($Status['stderr']);}

		pm_Settings::set('scan_'.$account."@".$domain,$idTask);


	}

    /**
     * Get Status progress
     *
     * @param $account		String Name of email account
     * @param $domain		String Domain Name of email account
     *
     * @return Array(2)		Percent of progress , Total Files to Checks
     */
	public static function Status($account,$domain){

		$path = $account . "@" . $domain;
		$logPath = Modules_FlexClamServer_Helper::TempPathLog() . $path . ".log";

		$fileManager = new pm_ServerFileManager();
		if (!$fileManager->fileExists($logPath)) {
			return [100,0];
		}else{
			do {
				if (!$fileManager->fileExists($logPath)) {
					break;
				}
				$log = json_decode($fileManager->fileGetContents($logPath));
				
			} while ($log == NULL);

			if($log == NULL){return [100,0];}

			if ($log->status==="task"){
				return [-1,0]; 
			} elseif ($log->status==="end"){
				return [100,0]; 
			} else {
				return [((double)$log->checks * 100) / (double)$log->files,$log->files]; 
			}
		}

	}

    /**
     * Get Information Task
     *
     * @param $account		String Name of email account
     * @param $domain		String Domain Name of email account
     *
     * @return Array		Status Item
     * @return Array		Data Informacion if task was end
     */
	public static function Info($account,$domain){

		$path = $account . "@" . $domain;
		$logPath = Modules_FlexClamServer_Helper::TempPathLog() . $path . ".log";

		$fileManager = new pm_ServerFileManager();
		if (!$fileManager->fileExists($logPath)) {
			pm_Settings::set('scan_'.$account."@".$domain,null);
			return ["status" => "none"];
		}else{

			$log = json_decode($fileManager->fileGetContents($logPath));

			if($log->status=="end"){
				return ["status" => $log->status, "checks" => $log->checks, "virus" => $log->virus, "warning" => [$log->warning]];
			}else{
				return ["status" => $log->status];
			}
		}

	}

    /**
     * Stop Checking and delete log
     *
     * @param $account		String Name of email account
     * @param $domain		String Domain Name of email account
     *
     * @return Boolean		True
     */
	public static function Stop($account,$domain){

		pm_Settings::set('scan_'.$account."@".$domain,null);
		
		$path = $account . "@" . $domain;
		$logPath = Modules_FlexClamServer_Helper::TempPathLog() . $path . ".log";

		$fileManager = new pm_ServerFileManager();
		if (!$fileManager->fileExists($logPath)) {
			return true;
		}else{

			$log = json_decode($fileManager->fileGetContents($logPath));

			if ($log->status==="end"){
				return true;
			} else {
				$fileManager->removeFile($logPath);
				return true;
			}
		}

	}

    /**
     * Get Task from ID
     *
     * @param $idTask		Numeric ID of Task
     *
     * @return Task Class(pm_LongTask_Task) or NULL if not exists
     */
	public static function Task($idTask){

		if($idTask==0){
			return null;
		}else{
		        $taskManager = new pm_LongTask_Manager();

			foreach ($taskManager->getTasks(["task_mail"]) as $task) {
				if ($task->getInstanceId() == $idTask){
					return  $task;
				}

			}
			return null;			
		}	

	}


}