<?php
/**
 * Copyright 2025 Flex Clam Server for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2025 Flex Clam Server for Plesk
 * @author Flex Antivirus <info@antivirus.flexservices.app>
 * @license Copyright
 */
class Modules_FlexClamServer_Settings{


    const DomExt="https://antivirus.flexservices.app";
    const Ext="Flex Clam Server";

     /**
     * Get Status System
     *
     * @return Array		Info List
     */
	public static function Status(){
		$Status = -1;
		$WD = false;
		$MS = "";
		$MSA = false;
		$mailenablefilter = "Flex";

		if( isset($_SESSION[pm_Context::getModuleInfo()->name]['Activity']) && ((time() - $_SESSION[pm_Context::getModuleInfo()->name]['Activity']) < 90) ){
			$Status = $_SESSION[pm_Context::getModuleInfo()->name]["status"];
		}

		if($Status !== 0){

			$info = pm_ApiCli::callSbin("FlexClamServer.exe",array("-json"),1);

			$_SESSION[pm_Context::getModuleInfo()->name]["status"] = $info['code'];

			$result = $info['stdout'];
			if($info['code']>0){$result = $info['stderr'];}

			$json = json_decode($result);


			$_SESSION[pm_Context::getModuleInfo()->name]["WD"] = $json->defender;
			$_SESSION[pm_Context::getModuleInfo()->name]["MS"] = $json->mailserver;
			$_SESSION[pm_Context::getModuleInfo()->name]["MSA"] = $json->mailserverantivirus;
			if($json->mailserver=="MailEnable"){
				$_SESSION[pm_Context::getModuleInfo()->name]["mailenablefilter"] = $json->mailenablefilter;
			}else{
				$_SESSION[pm_Context::getModuleInfo()->name]["mailenablefilter"] = $mailenablefilter;
			}

			$_SESSION[pm_Context::getModuleInfo()->name]['Activity'] = time();
		}
		
		$Status = $_SESSION[pm_Context::getModuleInfo()->name]["status"];
		$WD = $_SESSION[pm_Context::getModuleInfo()->name]["WD"];
		$MS = $_SESSION[pm_Context::getModuleInfo()->name]["MS"];
		$MSA = $_SESSION[pm_Context::getModuleInfo()->name]["MSA"];
		$mailenablefilter = $_SESSION[pm_Context::getModuleInfo()->name]["mailenablefilter"];

		return ["status" => (int)$Status , "WD" => (boolean)$WD, "MS" => $MS, "MSA" => $MSA , "mailenablefilter" => $mailenablefilter ];

	}

    /**
     * Read Setting File
     *
     * @param $Item		String => Item to find
     * @param $DefaultValue	Optional DefaultValue if not find Item
     *
     * @return Record		Value of Item if Found
     * @return Null		Null if Item not exists
     */
	public static function Get($Item , $DefaultValue = null,$file = 'Settings'){

		/* Check if there is any cache setting live */

		if(isset($_SESSION[pm_Context::getModuleInfo()->name][$file])){

			/* cache found, now check if cache is from last 1 min or more */


			if( isset($_SESSION[pm_Context::getModuleInfo()->name][$file.'_Activity']) && ((time() - $_SESSION[pm_Context::getModuleInfo()->name][$file.'_Activity']) > 60) ){
				/* old cache : destroy and not load */
				unset($_SESSION[pm_Context::getModuleInfo()->name][$file]);
				unset($_SESSION[pm_Context::getModuleInfo()->name][$file.'_Activity']);
			}else{

				/* catch cache found */
				$appjson = $_SESSION[pm_Context::getModuleInfo()->name][$file];

				if(!array_key_exists("Job",$appjson) || (array_key_exists("Job",$appjson) && $appjson["Job"]=='')){

					if( str_contains($Item, '.') ){
						if(isset($appjson[explode(".",$Item)[0]]) && is_array($appjson[explode(".",$Item)[0]])){
							if( !isset($appjson[explode(".",$Item)[0]][explode(".",$Item)[1]]) || is_null($appjson[explode(".",$Item)[0]][explode(".",$Item)[1]]) || !array_key_exists(explode(".",$Item)[1], $appjson[explode(".",$Item)[0]]) ){
								return $DefaultValue;
							}else{
								if($Item=="Job"){
									if($appjson[explode(".",$Item)[0]][explode(".",$Item)[1]]==''){return '';}
								}else{
									return $appjson[explode(".",$Item)[0]][explode(".",$Item)[1]];
								}
							}
						}else{
							return $DefaultValue;
						}
					}else{
						if( !isset($appjson[$Item]) || is_null($appjson[$Item]) || !array_key_exists($Item, $appjson)  ){
							return $DefaultValue;
						}else{
							if($Item=="Job"){
								if($appjson[$Item]==''){return '';}
							}else{
								return $appjson[$Item];
							}
						}
					}
				}
			}
		}

		/* no catch found and get information from file */

    		$fileManager = new pm_ServerFileManager();
		$filePath = pm_Context::getVarDir() . "\\".$file.".cfg";

		if (!$fileManager->fileExists($filePath)) {
			return $DefaultValue;
		}else{
			$appjson = json_decode($fileManager->fileGetContents($filePath), true);
			$_SESSION[pm_Context::getModuleInfo()->name][$file]=$appjson;
			$_SESSION[pm_Context::getModuleInfo()->name][$file.'_Activity'] = time();
			if( str_contains($Item, '.') ){
				if( !isset($appjson[explode(".",$Item)[0]][explode(".",$Item)[1]]) || is_null($appjson[explode(".",$Item)[0]][explode(".",$Item)[1]]) || !array_key_exists(explode(".",$Item)[1], $appjson[explode(".",$Item)[0]]) ){
					return $DefaultValue;
				}else{
					return $appjson[explode(".",$Item)[0]][explode(".",$Item)[1]];
				}
			}else{
				if( !isset($appjson[$Item]) || is_null($appjson[$Item]) || !array_key_exists($Item, $appjson) ){
					return $DefaultValue;
				}else{
					return $appjson[$Item];
				}
			}

		}

	}


    /**
     * Save Setting File
     *
     * @param $Item		String => Item to find
     * @param $Value		Value to save
     *
     */
	public static function Save($Item,$Value,$file = 'Settings'){

    		$fileManager = new pm_ServerFileManager();
		$filePath = pm_Context::getVarDir() . "\\".$file.".cfg";

		if (!$fileManager->fileExists($filePath)) {
			if( str_contains($Item, '.') ){
				$appjson[explode(".",$Item)[0]][] = [explode(".",$Item)[1] => $Value];
			}else{
				$appjson[$Item] = $Value;
			}
			$fileManager->filePutContents($filePath, json_encode($appjson, JSON_PRETTY_PRINT));

			/* Destroy cache if exists*/
			unset($_SESSION[pm_Context::getModuleInfo()->name][$file]);
		}else{
			$appjsonSession = (isset($_SESSION[pm_Context::getModuleInfo()->name][$file]) ? $_SESSION[pm_Context::getModuleInfo()->name][$file] : [] );
			$appjson = json_decode($fileManager->fileGetContents($filePath), true);
			if( str_contains($Item, '.') ){
				$appjson[explode(".",$Item)[0]][explode(".",$Item)[1]] = $Value;
			}else{
				$appjson[$Item] = $Value;
			}

			if($appjsonSession!==$appjson){
				$fileManager->filePutContents($filePath, json_encode($appjson, JSON_PRETTY_PRINT));
			}

			/* Refresh cache */
			$_SESSION[pm_Context::getModuleInfo()->name][$file]=$appjson;
			$_SESSION[pm_Context::getModuleInfo()->name][$file.'_Activity'] = time();
		}



	}
  

    /**
     * Delete Setting File
     *
     * @param $Item		String => Item to find
     *
     */
	public static function Delete($Item,$file = 'Settings'){

    		$fileManager = new pm_ServerFileManager();
		$filePath = pm_Context::getVarDir() . "\\".$file.".cfg";
		$found=false;

		if ($fileManager->fileExists($filePath)) {
			$appjson = json_decode($fileManager->fileGetContents($filePath), true);
			if( str_contains($Item, '.') ){
				if( isset( $appjson[explode(".",$Item)[0]][explode(".",$Item)[1]] ) ){unset($appjson[explode(".",$Item)[0]][explode(".",$Item)[1]]); $found=true;}
			}else{
				if( isset( $appjson[$Item] ) ){unset($appjson[$Item]);$found=true;}
			}

			if($found){
				$fileManager->filePutContents($filePath, json_encode($appjson, JSON_PRETTY_PRINT));

				/* Refresh cache */
				$_SESSION[pm_Context::getModuleInfo()->name][$file]=$appjson;
				$_SESSION[pm_Context::getModuleInfo()->name][$file.'_Activity'] = time();
			}
		}



	}

	public static function AutoTypeScan(){

		$taskId = pm_Settings::get('TaskId_AutoTypeScan',null);

		if ( $taskId !== null ) {
			try{
				$task = pm_Scheduler::getInstance()->getTaskById($taskId);
				pm_Scheduler::getInstance()->removeTask($task);
			}catch(Exception $e){}
		}

		$type = pm_Settings::get("AutoTypeScan", "night");
		$hour = '0';
		$min = '0';

		if($type=="night"){
			$hour = '23';
			$min = '59';
		}

		if($type=="morning"){
			$hour = '8';
			$min = '0';
		}
		if($type=="hour"){
			$hour = '*';
			$min = '0';
		}
		if($type=="disabled"){
			return true;
		}

		try{
			$task = new pm_Scheduler_Task();
				$task->setSchedule(array(
				'minute' => $min,
				'hour' => $hour,
				'dom' => '*',
				'month' => '*',
				'dow' => '*'
				    ));
			$task->setCmd('scan-task.php');

			pm_Scheduler::getInstance()->putTask($task);
			pm_Settings::set('TaskId_AutoTypeScan', $task->getId());
		}catch(Exception $e){}



	}

	public static function AutoTypeRam(){

		$taskId = pm_Settings::get('TaskId_AutoTypeRam',null);

		if ( $taskId !== null ) {
			try{
				$task = pm_Scheduler::getInstance()->getTaskById($taskId);
				pm_Scheduler::getInstance()->removeTask($task);
			}catch(Exception $e){}
		}

		$type = pm_Settings::get("AutoTypeRam", "night");
		$hour = '0';
		$min = '0';

		if($type=="night"){
			$hour = '3';
			$min = '0';
		}

		if($type=="morning"){
			$hour = '9';
			$min = '0';
		}
		if($type=="hour"){
			$hour = '*';
			$min = '0';
		}
		if($type=="disabled"){
			return true;
		}

		try{
			$task = new pm_Scheduler_Task();
				$task->setSchedule(array(
				'minute' => $min,
				'hour' => $hour,
				'dom' => '*',
				'month' => '*',
				'dow' => '*'
				    ));
			$task->setCmd('ram-task.php');

			pm_Scheduler::getInstance()->putTask($task);
			pm_Settings::set('TaskId_AutoTypeRam', $task->getId());
		}catch(Exception $e){}



	}

    /**
     * Get Length String and detect null as 0
     *
     * @param $Value		String => Value
     *
     * @return Numeric
     */
	public static function GetLength($Value){

		if ($Value === null || $Value === ''){
		  	return 0;
		}else{
			return strlen($Value);
		}
	}

    /**
     * Return String with Format Date
     *
     * @param $date		String  Date and Languaje Format
     * @param $format		String  Languaje Format
     *
     * @return String		Format output
     * @return String		Empty String if wrong @param
     */
	public static function FormatDateOutput($date,$format){



		if(self::GetLength($date)==0){
			return "";
		}

		$output=$format;
		$strdate=$date;
		$strtime="";


		if(is_numeric($date)){$strdate = (string)date("Y-m-d H:i:s", $date);}

		if (str_contains($strdate, ' ')===True){
			$mixdate = $strdate;
			$strdate=explode(' ', $mixdate)[0];
			$strtime=explode(' ', $mixdate)[1];
		}

		if (str_contains($strdate, '-')) {
			$ardate=explode("-", $strdate);
			$output=str_replace("YYYY",$ardate[0],$output);
			$output=str_replace("MM",$ardate[1],$output);
			$output=str_replace("DD",$ardate[2],$output);

		} elseif (str_contains($strdate, '/')) {
			$ardate=explode("/", $strdate);

			$output=str_replace("YYYY",$ardate[2],$output);
			$output=str_replace("MM",$ardate[1],$output);
			$output=str_replace("DD",$ardate[0],$output);

		} else {

			$output=str_replace("YYYY",date('Y',$strdate),$output);
			$output=str_replace("MM",date('m',$strdate),$output);
			$output=str_replace("DD",date('d',$strdate),$output);
		}


		if ( str_contains($format, ":") && self::GetLength($strtime)>0 ){
			$artime = [];
			if (str_contains($strtime, ":")) {$artime=explode(":", $strtime);}
			if (str_contains($strtime, "-")) {$artime=explode("-", $strtime);}

			$output=str_replace("hh",$artime[0],$output);
			$output=str_replace("mm",$artime[1],$output);

		}


		return $output;
	}


} // end
