<?php
/**
 * Copyright 2025 Flex Clam Server for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2025 Flex Clam Server for Plesk
 * @author Flex Antivirus <info@antivirus.flexservices.app>
 * @license Copyright
 */

class Modules_FlexClamServer_Task_Mail extends pm_LongTask_Task{

    public $hasDangerousMessage = true;
    public $trackProgress = true;
    public $hidden = false;
    public $poolSize = 2;
    public $progress = -1;
    public $timeout = null;
    public $countfiles = 0;
    public $countfilesUpdate = 0;

    public function run(){

	$this->timeout = new DateTime('now');
        Modules_FlexClamServer_Mail::Start($this->getParam("name"),$this->getParam("domain"),$this->getInstanceId());
	sleep(1);

	$info = Modules_FlexClamServer_Mail::Status($this->getParam("name"),$this->getParam("domain"));

	$this->progress = $info[0];
	$this->countfiles = $info[1];
	$this->countfilesUpdate = $info[1];


	$this->updateProgress(($this->progress<0 ? 0 : $this->progress));

	$timeout = new DateTime('now');

	while ($this->progress < 100) {
		sleep(1);
		if($this->progress<1){
			$nowtimeout = new DateTime('now');
			$diff_mins = abs($this->timeout->getTimestamp() - $nowtimeout->getTimestamp()) / 60;
			if(($this->progress>-1 && $diff_mins > 2) || ($this->progress==-1 && $diff_mins > 20)){
				Modules_FlexClamServer_Mail::Stop($this->getParam("name"),$this->getParam("domain"));
				throw new pm_Exception('ERROR : Timeout');
			}
		}
		$info = Modules_FlexClamServer_Mail::Status($this->getParam("name"),$this->getParam("domain"));
		if ($this->progress==-1 && $info[0]!=-1){$timeout = new DateTime('now');}
		$this->progress = $info[0];
		$this->countfiles = $info[1];


		if($this->countfilesUpdate==$this->countfiles){
			$diff_mins = abs($this->timeout->getTimestamp() - $timeout->getTimestamp()) / 60;
			if($diff_mins > 4){
				Modules_FlexClamServer_Mail::Stop($this->getParam("name"),$this->getParam("domain"));
				throw new pm_Exception('ERROR : Timeout');
			}
		}else{
			$timeout = new DateTime('now');
		}

		$this->countfilesUpdate=$this->countfiles;

		$this->updateProgress(($this->progress<0 ? 0 : $this->progress));


	}

    }

    public function statusMessage(){

        switch ($this->getStatus()) {
            case static::STATUS_RUNNING:
		if($this->getProgress()==0){
			if($this->progress<0){
		                return pm_Locale::lmsg('Email.Task', ["idTask" => $this->getInstanceId(),"mail" => $this->getParam("name")."@".$this->getParam("domain")]);
			}else{
		                return pm_Locale::lmsg('Email.Wait', ["idTask" => $this->getInstanceId(),"mail" => $this->getParam("name")."@".$this->getParam("domain")]);
			}
		}else{
        	        return pm_Locale::lmsg('Email.Run', ["idTask" => $this->getInstanceId(),"files" => $this->countfiles,"mail" => $this->getParam("name")."@".$this->getParam("domain")]);
		}
            case static::STATUS_DONE:
		if($this->getParam("virus")>0){
	                return pm_Locale::lmsg('Email.Virus', ["idTask" => $this->getInstanceId(),"mail" => $this->getParam("name")."@".$this->getParam("domain")]);
		}else{
	                return pm_Locale::lmsg('Email.Done',["idTask" => $this->getInstanceId(),"mail" => $this->getParam("name")."@".$this->getParam("domain")]);
		}
        }
        return '';
   
    }

    public function onStart(){
	pm_Settings::set('scan_'.$this->getParam("name")."@".$this->getParam("domain"),$this->getInstanceId());
        $this->setParams(['virus' => 0]);
    }

    public function onDone(){
	$this->progress = 100;
	pm_Settings::set('scan_'.$this->getParam("name")."@".$this->getParam("domain"),null);

	$info = Modules_FlexClamServer_Mail::Info($this->getParam("name"),$this->getParam("domain"));
	if($info["status"]=="end"){
		$this->setParams(['virus' => $info["virus"]]);
	}

	pm_Log::info("FlexClamServer : Finish Scan " . $this->getParam("name")."@".$this->getParam("domain"));

    }

    public function onError(Exception $e){
	pm_Log::err("FlexClamServer : Finish Scan " . $this->getParam("name")."@".$this->getParam("domain"));
	pm_Settings::set('scan_'.$this->getParam("name")."@".$this->getParam("domain"),null);
	Modules_FlexClamServer_Mail::Stop($this->getParam("name"),$this->getParam("domain"));
    }


}