<?php
/**
 * Copyright 2025 Flex Clam Server for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2025 Flex Clam Server for Plesk
 * @author Flex Antivirus <info@antivirus.flexservices.app>
 * @license Copyright
 */

class Modules_FlexClamServer_Task_Scan extends pm_LongTask_Task{

    public $hasDangerousMessage = true;
    public $trackProgress = true;
    public $hidden = false;
    public $poolSize = 1;
    public $progress = -1;
    public $timeout = null;
    public $countfiles = 0;
    public $countfilesUpdate = 0;


    public function run(){

	$this->timeout = new DateTime('now');
        Modules_FlexClamServer_Check::Start($this->getParam("domainId"),$this->getInstanceId());
	sleep(1);

	$info = Modules_FlexClamServer_Check::Status($this->getParam("domainId"));

	$this->progress = $info[0];
	$this->countfiles = $info[1];
	$this->countfilesUpdate = $info[1];

	$this->updateProgress(($this->progress<0 ? 0 : $this->progress));

	$timeout = new DateTime('now');

	while ($this->progress < 100) {
		sleep(1);
		if($this->progress==0){
			$nowtimeout = new DateTime('now');
			$diff_mins = abs($this->timeout->getTimestamp() - $nowtimeout->getTimestamp()) / 60;
			if($diff_mins > 2){
				Modules_FlexClamServer_Check::Stop($this->getParam("domainId"));
				pm_Settings::set('scan_lock',0);
				throw new pm_Exception('ERROR : Timeout');
			}
		}

		$info = Modules_FlexClamServer_Check::Status($this->getParam("domainId"));
		if ($this->progress==-1 && $info[0]!=-1){$timeout = new DateTime('now');}
		$this->progress = $info[0];
		$this->countfiles = $info[1];

		if($this->countfilesUpdate==$this->countfiles){
			$diff_mins = abs($this->timeout->getTimestamp() - $timeout->getTimestamp()) / 60;
			if($diff_mins > 3){
				Modules_FlexClamServer_Check::Stop($this->getParam("domainId"));
				throw new pm_Exception('ERROR : Timeout');
			}
		}else{
			$timeout = new DateTime('now');
		}

		$this->countfilesUpdate=$this->countfiles;
		$this->updateProgress(($this->progress<0 ? 0 : $this->progress));


	}

    }

    public function statusMessage(){

        switch ($this->getStatus()) {
            case static::STATUS_RUNNING:
		if($this->getProgress()==0){
			if($this->progress<0){
		                return pm_Locale::lmsg('Scan.Task', ["idTask" => $this->getInstanceId(), "link" => pm_Context::getActionUrl("index","cancel")."/task/".$this->getInstanceId(),"domain" => $this->getParam("domain")]);
			}else{
		                return pm_Locale::lmsg('Scan.Wait', ["idTask" => $this->getInstanceId(),"link" => pm_Context::getActionUrl("index","cancel")."/task/".$this->getId(),"domain" => $this->getParam("domain")]);
			}
		}else{
        	        return pm_Locale::lmsg('Scan.Run', ["files" => $this->countfiles,"idTask" => $this->getInstanceId(),"link" => pm_Context::getActionUrl("index","cancel")."/task/".$this->getInstanceId(),"domain" => $this->getParam("domain")]);
		}
            case static::STATUS_DONE:
		if($this->getParam("virus")>0){
	                return pm_Locale::lmsg('Scan.Virus', ["link" => pm_Context::getActionUrl("index","virus"),"domain" => $this->getParam("domain")]);
		}else{
	                return pm_Locale::lmsg('Scan.Done', ["link" => pm_Context::getActionUrl("index","overview"),"domain" => $this->getParam("domain")]);
		}
        }
        return '';
   
    }

    public function onStart(){
	pm_Settings::set('scan_lock',1);
	pm_Domain::getByDomainId($this->getParam("domainId"))->setSetting("idTask",0);
        $this->setParams(['domain' => pm_Domain::getByDomainId($this->getParam("domainId"))->getDisplayName()]);
        $this->setParams(['lastScan' => pm_Domain::getByDomainId($this->getParam("domainId"))->getSetting("lastScan",null)]);
        $this->setParams(['path' => pm_Domain::getByDomainId($this->getParam("domainId"))->getHomePath()]);
        $this->setParams(['domain' => pm_Domain::getByDomainId($this->getParam("domainId"))->getDisplayName()]);
        $this->setParams(['virus' => 0]);
	Modules_FlexClamServer_Helper::ScanStatusFlag($this->getParam("domainId"), true);

    }

    public function onDone(){
	$this->progress = 100;
	pm_Settings::set('scan_lock',0);

	pm_Domain::getByDomainId($this->getParam("domainId"))->setSetting("idTask",0);
	Modules_FlexClamServer_Helper::ScanStatusFlag($this->getParam("domainId"), false);

	$info = Modules_FlexClamServer_Check::Info($this->getParam("domainId"));
	if($info["status"]=="end"){
		$this->setParams(['virus' => $info["virus"]]);
		pm_Domain::getByDomainId($this->getParam("domainId"))->setSetting("warnings",$info["virus"]);


		if ((int)$info["virus"]>0){

			$notificationManager = new pm_Notification();
		        $notificationManager->send("alert", ["customTitle" => "Virus","customMessage" => pm_Locale::lmsg("noti.NotiFoundVirus"), "customLink" => pm_Context::getBaseUrl() . "index.php/index/virus" ]);

			if(Modules_FlexClamServer_Settings::Get("EnableNotiEmail","0")=="1"){
				$contentVirus = "";
				foreach ((array)$info["warning"] as $listVirus){
					$contentVirus = $contentVirus . "<li>";
					$contentVirus = $contentVirus . $listVirus["name"] . " (". $listVirus["file"]. ")";
					$contentVirus = $contentVirus . "</li>";
				}
				$notificationManager->send("email_admin", ['subject-text' => pm_Domain::getByDomainId($this->getParam("domainId"))->getDisplayName() . " : " . pm_Locale::lmsg('noti.typeAlert'),'message-text' => pm_Locale::lmsg("noti.NotiFoundVirus"). "<br>" . $contentVirus]);
			}

		}

	}

	pm_Log::info("FlexClamServer : Finish Scan " . $this->getParam("domain"));

	if($this->getParam("remove") == "1"){
	        $taskManager = new pm_LongTask_Manager();
		$taskManager->cancel($this);
	}


    }

    public function onError(Exception $e){
	pm_Log::err("FlexClamServer : Error Scan " . $this->getParam("domain"));
	Modules_FlexClamServer_Check::Stop($this->getParam("domainId"));
	pm_Domain::getByDomainId($this->getParam("domainId"))->setSetting("lastScan",$this->getParam("lastScan"));
	pm_Settings::set('scan_lock',0);
    }


}